/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.4.0 (build: 2013-06-26 16:27:34 UTC)
 *  on 2013-07-15 at 19:46:18 UTC 
 */

package com.google.api.services.books;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.common.base.Preconditions;

/**
 * Service definition for Books (v1).
 *
 * <p>
 * Lets you search for books and manage your Google Books library.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/books/docs/v1/getting_started" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link BooksRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Books extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the Books API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "books/v1/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Books(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Books(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Bookshelves collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Books books = new Books(...);}
   *   {@code Books.Bookshelves.List request = books.bookshelves().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Bookshelves bookshelves() {
    return new Bookshelves();
  }

  /**
   * The "bookshelves" collection of methods.
   */
  public class Bookshelves {

    /**
     * Retrieves metadata for a specific bookshelf for the specified user.
     *
     * Create a request for the method "bookshelves.get".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param userId ID of user for whom to retrieve bookshelves.
     * @param shelf ID of bookshelf to retrieve.
     * @return the request
     */
    public Get get(String userId, String shelf) throws java.io.IOException {
      Get result = new Get(userId, shelf);
      initialize(result);
      return result;
    }

    public class Get extends BooksRequest<com.google.api.services.books.model.Bookshelf> {

      private static final String REST_PATH = "users/{userId}/bookshelves/{shelf}";

      /**
       * Retrieves metadata for a specific bookshelf for the specified user.
       *
       * Create a request for the method "bookshelves.get".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param userId ID of user for whom to retrieve bookshelves.
       * @param shelf ID of bookshelf to retrieve.
       * @since 1.13
       */
      protected Get(String userId, String shelf) {
        super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Bookshelf.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
        this.shelf = Preconditions.checkNotNull(shelf, "Required parameter shelf must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** ID of user for whom to retrieve bookshelves. */
      @com.google.api.client.util.Key
      private String userId;

      /** ID of user for whom to retrieve bookshelves.
       */
      public String getUserId() {
        return userId;
      }

      /** ID of user for whom to retrieve bookshelves. */
      public Get setUserId(String userId) {
        this.userId = userId;
        return this;
      }

      /** ID of bookshelf to retrieve. */
      @com.google.api.client.util.Key
      private String shelf;

      /** ID of bookshelf to retrieve.
       */
      public String getShelf() {
        return shelf;
      }

      /** ID of bookshelf to retrieve. */
      public Get setShelf(String shelf) {
        this.shelf = shelf;
        return this;
      }

      /** String to identify the originator of this request. */
      @com.google.api.client.util.Key
      private String source;

      /** String to identify the originator of this request.
       */
      public String getSource() {
        return source;
      }

      /** String to identify the originator of this request. */
      public Get setSource(String source) {
        this.source = source;
        return this;
      }

    }
    /**
     * Retrieves a list of public bookshelves for the specified user.
     *
     * Create a request for the method "bookshelves.list".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param userId ID of user for whom to retrieve bookshelves.
     * @return the request
     */
    public List list(String userId) throws java.io.IOException {
      List result = new List(userId);
      initialize(result);
      return result;
    }

    public class List extends BooksRequest<com.google.api.services.books.model.Bookshelves> {

      private static final String REST_PATH = "users/{userId}/bookshelves";

      /**
       * Retrieves a list of public bookshelves for the specified user.
       *
       * Create a request for the method "bookshelves.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param userId ID of user for whom to retrieve bookshelves.
       * @since 1.13
       */
      protected List(String userId) {
        super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Bookshelves.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** ID of user for whom to retrieve bookshelves. */
      @com.google.api.client.util.Key
      private String userId;

      /** ID of user for whom to retrieve bookshelves.
       */
      public String getUserId() {
        return userId;
      }

      /** ID of user for whom to retrieve bookshelves. */
      public List setUserId(String userId) {
        this.userId = userId;
        return this;
      }

      /** String to identify the originator of this request. */
      @com.google.api.client.util.Key
      private String source;

      /** String to identify the originator of this request.
       */
      public String getSource() {
        return source;
      }

      /** String to identify the originator of this request. */
      public List setSource(String source) {
        this.source = source;
        return this;
      }

    }

    /**
     * An accessor for creating requests from the Volumes collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Books books = new Books(...);}
     *   {@code Books.Volumes.List request = books.volumes().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Volumes volumes() {
      return new Volumes();
    }

    /**
     * The "volumes" collection of methods.
     */
    public class Volumes {

      /**
       * Retrieves volumes in a specific bookshelf for the specified user.
       *
       * Create a request for the method "volumes.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param userId ID of user for whom to retrieve bookshelf volumes.
       * @param shelf ID of bookshelf to retrieve volumes.
       * @return the request
       */
      public List list(String userId, String shelf) throws java.io.IOException {
        List result = new List(userId, shelf);
        initialize(result);
        return result;
      }

      public class List extends BooksRequest<com.google.api.services.books.model.Volumes> {

        private static final String REST_PATH = "users/{userId}/bookshelves/{shelf}/volumes";

        /**
         * Retrieves volumes in a specific bookshelf for the specified user.
         *
         * Create a request for the method "volumes.list".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param userId ID of user for whom to retrieve bookshelf volumes.
         * @param shelf ID of bookshelf to retrieve volumes.
         * @since 1.13
         */
        protected List(String userId, String shelf) {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Volumes.class);
          this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
          this.shelf = Preconditions.checkNotNull(shelf, "Required parameter shelf must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** ID of user for whom to retrieve bookshelf volumes. */
        @com.google.api.client.util.Key
        private String userId;

        /** ID of user for whom to retrieve bookshelf volumes.
         */
        public String getUserId() {
          return userId;
        }

        /** ID of user for whom to retrieve bookshelf volumes. */
        public List setUserId(String userId) {
          this.userId = userId;
          return this;
        }

        /** ID of bookshelf to retrieve volumes. */
        @com.google.api.client.util.Key
        private String shelf;

        /** ID of bookshelf to retrieve volumes.
         */
        public String getShelf() {
          return shelf;
        }

        /** ID of bookshelf to retrieve volumes. */
        public List setShelf(String shelf) {
          this.shelf = shelf;
          return this;
        }

        /** Set to true to show pre-ordered books. Defaults to false. */
        @com.google.api.client.util.Key
        private Boolean showPreorders;

        /** Set to true to show pre-ordered books. Defaults to false.
         */
        public Boolean getShowPreorders() {
          return showPreorders;
        }

        /** Set to true to show pre-ordered books. Defaults to false. */
        public List setShowPreorders(Boolean showPreorders) {
          this.showPreorders = showPreorders;
          return this;
        }

        /** Maximum number of results to return */
        @com.google.api.client.util.Key
        private Long maxResults;

        /** Maximum number of results to return

       [minimum: 0]
         */
        public Long getMaxResults() {
          return maxResults;
        }

        /** Maximum number of results to return */
        public List setMaxResults(Long maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public List setSource(String source) {
          this.source = source;
          return this;
        }

        /** Index of the first element to return (starts at 0) */
        @com.google.api.client.util.Key
        private Long startIndex;

        /** Index of the first element to return (starts at 0)

       [minimum: 0]
         */
        public Long getStartIndex() {
          return startIndex;
        }

        /** Index of the first element to return (starts at 0) */
        public List setStartIndex(Long startIndex) {
          this.startIndex = startIndex;
          return this;
        }

      }

    }
  }

  /**
   * An accessor for creating requests from the Cloudloading collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Books books = new Books(...);}
   *   {@code Books.Cloudloading.List request = books.cloudloading().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Cloudloading cloudloading() {
    return new Cloudloading();
  }

  /**
   * The "cloudloading" collection of methods.
   */
  public class Cloudloading {

    /**
     * Create a request for the method "cloudloading.addBook".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link AddBook#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public AddBook addBook() throws java.io.IOException {
      AddBook result = new AddBook();
      initialize(result);
      return result;
    }

    public class AddBook extends BooksRequest<com.google.api.services.books.model.BooksCloudloadingResource> {

      private static final String REST_PATH = "cloudloading/addBook";

      /**
       * Create a request for the method "cloudloading.addBook".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link AddBook#execute()} method to invoke the remote operation. <p>
       * {@link AddBook#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected AddBook() {
        super(Books.this, "POST", REST_PATH, null, com.google.api.services.books.model.BooksCloudloadingResource.class);
      }

      @Override
      public AddBook setAlt(String alt) {
        return (AddBook) super.setAlt(alt);
      }

      @Override
      public AddBook setFields(String fields) {
        return (AddBook) super.setFields(fields);
      }

      @Override
      public AddBook setKey(String key) {
        return (AddBook) super.setKey(key);
      }

      @Override
      public AddBook setOauthToken(String oauthToken) {
        return (AddBook) super.setOauthToken(oauthToken);
      }

      @Override
      public AddBook setPrettyPrint(Boolean prettyPrint) {
        return (AddBook) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public AddBook setQuotaUser(String quotaUser) {
        return (AddBook) super.setQuotaUser(quotaUser);
      }

      @Override
      public AddBook setUserIp(String userIp) {
        return (AddBook) super.setUserIp(userIp);
      }

      @com.google.api.client.util.Key("upload_client_token")
      private String uploadClientToken;

      /**

       */
      public String getUploadClientToken() {
        return uploadClientToken;
      }

      public AddBook setUploadClientToken(String uploadClientToken) {
        this.uploadClientToken = uploadClientToken;
        return this;
      }

      /** A drive document id. The upload_client_token must not be set. */
      @com.google.api.client.util.Key("drive_document_id")
      private String driveDocumentId;

      /** A drive document id. The upload_client_token must not be set.
       */
      public String getDriveDocumentId() {
        return driveDocumentId;
      }

      /** A drive document id. The upload_client_token must not be set. */
      public AddBook setDriveDocumentId(String driveDocumentId) {
        this.driveDocumentId = driveDocumentId;
        return this;
      }

      /** The document MIME type. It can be set only if the drive_document_id is set. */
      @com.google.api.client.util.Key("mime_type")
      private String mimeType;

      /** The document MIME type. It can be set only if the drive_document_id is set.
       */
      public String getMimeType() {
        return mimeType;
      }

      /** The document MIME type. It can be set only if the drive_document_id is set. */
      public AddBook setMimeType(String mimeType) {
        this.mimeType = mimeType;
        return this;
      }

      /** The document name. It can be set only if the drive_document_id is set. */
      @com.google.api.client.util.Key
      private String name;

      /** The document name. It can be set only if the drive_document_id is set.
       */
      public String getName() {
        return name;
      }

      /** The document name. It can be set only if the drive_document_id is set. */
      public AddBook setName(String name) {
        this.name = name;
        return this;
      }

    }
    /**
     * Remove the book and its contents
     *
     * Create a request for the method "cloudloading.deleteBook".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link DeleteBook#execute()} method to invoke the remote operation.
     *
     * @param volumeId The id of the book to be removed.
     * @return the request
     */
    public DeleteBook deleteBook(String volumeId) throws java.io.IOException {
      DeleteBook result = new DeleteBook(volumeId);
      initialize(result);
      return result;
    }

    public class DeleteBook extends BooksRequest<Void> {

      private static final String REST_PATH = "cloudloading/deleteBook";

      /**
       * Remove the book and its contents
       *
       * Create a request for the method "cloudloading.deleteBook".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link DeleteBook#execute()} method to invoke the remote operation. <p>
       * {@link DeleteBook#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param volumeId The id of the book to be removed.
       * @since 1.13
       */
      protected DeleteBook(String volumeId) {
        super(Books.this, "POST", REST_PATH, null, Void.class);
        this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
      }

      @Override
      public DeleteBook setAlt(String alt) {
        return (DeleteBook) super.setAlt(alt);
      }

      @Override
      public DeleteBook setFields(String fields) {
        return (DeleteBook) super.setFields(fields);
      }

      @Override
      public DeleteBook setKey(String key) {
        return (DeleteBook) super.setKey(key);
      }

      @Override
      public DeleteBook setOauthToken(String oauthToken) {
        return (DeleteBook) super.setOauthToken(oauthToken);
      }

      @Override
      public DeleteBook setPrettyPrint(Boolean prettyPrint) {
        return (DeleteBook) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public DeleteBook setQuotaUser(String quotaUser) {
        return (DeleteBook) super.setQuotaUser(quotaUser);
      }

      @Override
      public DeleteBook setUserIp(String userIp) {
        return (DeleteBook) super.setUserIp(userIp);
      }

      /** The id of the book to be removed. */
      @com.google.api.client.util.Key
      private String volumeId;

      /** The id of the book to be removed.
       */
      public String getVolumeId() {
        return volumeId;
      }

      /** The id of the book to be removed. */
      public DeleteBook setVolumeId(String volumeId) {
        this.volumeId = volumeId;
        return this;
      }

    }
    /**
     * Create a request for the method "cloudloading.updateBook".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link UpdateBook#execute()} method to invoke the remote operation.
     *
     * @param content the {@link com.google.api.services.books.model.BooksCloudloadingResource}
     * @return the request
     */
    public UpdateBook updateBook(com.google.api.services.books.model.BooksCloudloadingResource content) throws java.io.IOException {
      UpdateBook result = new UpdateBook(content);
      initialize(result);
      return result;
    }

    public class UpdateBook extends BooksRequest<com.google.api.services.books.model.BooksCloudloadingResource> {

      private static final String REST_PATH = "cloudloading/updateBook";

      /**
       * Create a request for the method "cloudloading.updateBook".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link UpdateBook#execute()} method to invoke the remote operation. <p>
       * {@link UpdateBook#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param content the {@link com.google.api.services.books.model.BooksCloudloadingResource}
       * @since 1.13
       */
      protected UpdateBook(com.google.api.services.books.model.BooksCloudloadingResource content) {
        super(Books.this, "POST", REST_PATH, content, com.google.api.services.books.model.BooksCloudloadingResource.class);
      }

      @Override
      public UpdateBook setAlt(String alt) {
        return (UpdateBook) super.setAlt(alt);
      }

      @Override
      public UpdateBook setFields(String fields) {
        return (UpdateBook) super.setFields(fields);
      }

      @Override
      public UpdateBook setKey(String key) {
        return (UpdateBook) super.setKey(key);
      }

      @Override
      public UpdateBook setOauthToken(String oauthToken) {
        return (UpdateBook) super.setOauthToken(oauthToken);
      }

      @Override
      public UpdateBook setPrettyPrint(Boolean prettyPrint) {
        return (UpdateBook) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public UpdateBook setQuotaUser(String quotaUser) {
        return (UpdateBook) super.setQuotaUser(quotaUser);
      }

      @Override
      public UpdateBook setUserIp(String userIp) {
        return (UpdateBook) super.setUserIp(userIp);
      }

    }

  }

  /**
   * An accessor for creating requests from the Layers collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Books books = new Books(...);}
   *   {@code Books.Layers.List request = books.layers().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Layers layers() {
    return new Layers();
  }

  /**
   * The "layers" collection of methods.
   */
  public class Layers {

    /**
     * Gets the layer summary for a volume.
     *
     * Create a request for the method "layers.get".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param volumeId The volume to retrieve layers for.
     * @param summaryId The ID for the layer to get the summary for.
     * @return the request
     */
    public Get get(String volumeId, String summaryId) throws java.io.IOException {
      Get result = new Get(volumeId, summaryId);
      initialize(result);
      return result;
    }

    public class Get extends BooksRequest<com.google.api.services.books.model.Layersummary> {

      private static final String REST_PATH = "volumes/{volumeId}/layersummary/{summaryId}";

      /**
       * Gets the layer summary for a volume.
       *
       * Create a request for the method "layers.get".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param volumeId The volume to retrieve layers for.
       * @param summaryId The ID for the layer to get the summary for.
       * @since 1.13
       */
      protected Get(String volumeId, String summaryId) {
        super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Layersummary.class);
        this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
        this.summaryId = Preconditions.checkNotNull(summaryId, "Required parameter summaryId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The volume to retrieve layers for. */
      @com.google.api.client.util.Key
      private String volumeId;

      /** The volume to retrieve layers for.
       */
      public String getVolumeId() {
        return volumeId;
      }

      /** The volume to retrieve layers for. */
      public Get setVolumeId(String volumeId) {
        this.volumeId = volumeId;
        return this;
      }

      /** The ID for the layer to get the summary for. */
      @com.google.api.client.util.Key
      private String summaryId;

      /** The ID for the layer to get the summary for.
       */
      public String getSummaryId() {
        return summaryId;
      }

      /** The ID for the layer to get the summary for. */
      public Get setSummaryId(String summaryId) {
        this.summaryId = summaryId;
        return this;
      }

      /** String to identify the originator of this request. */
      @com.google.api.client.util.Key
      private String source;

      /** String to identify the originator of this request.
       */
      public String getSource() {
        return source;
      }

      /** String to identify the originator of this request. */
      public Get setSource(String source) {
        this.source = source;
        return this;
      }

      /** The content version for the requested volume. */
      @com.google.api.client.util.Key
      private String contentVersion;

      /** The content version for the requested volume.
       */
      public String getContentVersion() {
        return contentVersion;
      }

      /** The content version for the requested volume. */
      public Get setContentVersion(String contentVersion) {
        this.contentVersion = contentVersion;
        return this;
      }

    }
    /**
     * List the layer summaries for a volume.
     *
     * Create a request for the method "layers.list".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param volumeId The volume to retrieve layers for.
     * @return the request
     */
    public List list(String volumeId) throws java.io.IOException {
      List result = new List(volumeId);
      initialize(result);
      return result;
    }

    public class List extends BooksRequest<com.google.api.services.books.model.Layersummaries> {

      private static final String REST_PATH = "volumes/{volumeId}/layersummary";

      /**
       * List the layer summaries for a volume.
       *
       * Create a request for the method "layers.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param volumeId The volume to retrieve layers for.
       * @since 1.13
       */
      protected List(String volumeId) {
        super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Layersummaries.class);
        this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** The volume to retrieve layers for. */
      @com.google.api.client.util.Key
      private String volumeId;

      /** The volume to retrieve layers for.
       */
      public String getVolumeId() {
        return volumeId;
      }

      /** The volume to retrieve layers for. */
      public List setVolumeId(String volumeId) {
        this.volumeId = volumeId;
        return this;
      }

      /** The value of the nextToken from the previous page. */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The value of the nextToken from the previous page.
       */
      public String getPageToken() {
        return pageToken;
      }

      /** The value of the nextToken from the previous page. */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The content version for the requested volume. */
      @com.google.api.client.util.Key
      private String contentVersion;

      /** The content version for the requested volume.
       */
      public String getContentVersion() {
        return contentVersion;
      }

      /** The content version for the requested volume. */
      public List setContentVersion(String contentVersion) {
        this.contentVersion = contentVersion;
        return this;
      }

      /** Maximum number of results to return */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** Maximum number of results to return

     [minimum: 0] [maximum: 200]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** String to identify the originator of this request. */
      @com.google.api.client.util.Key
      private String source;

      /** String to identify the originator of this request.
       */
      public String getSource() {
        return source;
      }

      /** String to identify the originator of this request. */
      public List setSource(String source) {
        this.source = source;
        return this;
      }

    }

    /**
     * An accessor for creating requests from the AnnotationData collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Books books = new Books(...);}
     *   {@code Books.AnnotationData.List request = books.annotationData().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public AnnotationData annotationData() {
      return new AnnotationData();
    }

    /**
     * The "annotationData" collection of methods.
     */
    public class AnnotationData {

      /**
       * Gets the annotation data.
       *
       * Create a request for the method "annotationData.get".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param volumeId The volume to retrieve annotations for.
       * @param layerId The ID for the layer to get the annotations.
       * @param annotationDataId The ID of the annotation data to retrieve.
       * @param contentVersion The content version for the volume you are trying to retrieve.
       * @return the request
       */
      public Get get(String volumeId, String layerId, String annotationDataId, String contentVersion) throws java.io.IOException {
        Get result = new Get(volumeId, layerId, annotationDataId, contentVersion);
        initialize(result);
        return result;
      }

      public class Get extends BooksRequest<com.google.api.services.books.model.Annotationdata> {

        private static final String REST_PATH = "volumes/{volumeId}/layers/{layerId}/data/{annotationDataId}";

        /**
         * Gets the annotation data.
         *
         * Create a request for the method "annotationData.get".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
         * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param volumeId The volume to retrieve annotations for.
         * @param layerId The ID for the layer to get the annotations.
         * @param annotationDataId The ID of the annotation data to retrieve.
         * @param contentVersion The content version for the volume you are trying to retrieve.
         * @since 1.13
         */
        protected Get(String volumeId, String layerId, String annotationDataId, String contentVersion) {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Annotationdata.class);
          this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
          this.layerId = Preconditions.checkNotNull(layerId, "Required parameter layerId must be specified.");
          this.annotationDataId = Preconditions.checkNotNull(annotationDataId, "Required parameter annotationDataId must be specified.");
          this.contentVersion = Preconditions.checkNotNull(contentVersion, "Required parameter contentVersion must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get setAlt(String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setFields(String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUserIp(String userIp) {
          return (Get) super.setUserIp(userIp);
        }

        /** The volume to retrieve annotations for. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** The volume to retrieve annotations for.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** The volume to retrieve annotations for. */
        public Get setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /** The ID for the layer to get the annotations. */
        @com.google.api.client.util.Key
        private String layerId;

        /** The ID for the layer to get the annotations.
         */
        public String getLayerId() {
          return layerId;
        }

        /** The ID for the layer to get the annotations. */
        public Get setLayerId(String layerId) {
          this.layerId = layerId;
          return this;
        }

        /** The ID of the annotation data to retrieve. */
        @com.google.api.client.util.Key
        private String annotationDataId;

        /** The ID of the annotation data to retrieve.
         */
        public String getAnnotationDataId() {
          return annotationDataId;
        }

        /** The ID of the annotation data to retrieve. */
        public Get setAnnotationDataId(String annotationDataId) {
          this.annotationDataId = annotationDataId;
          return this;
        }

        /** The content version for the volume you are trying to retrieve. */
        @com.google.api.client.util.Key
        private String contentVersion;

        /** The content version for the volume you are trying to retrieve.
         */
        public String getContentVersion() {
          return contentVersion;
        }

        /** The content version for the volume you are trying to retrieve. */
        public Get setContentVersion(String contentVersion) {
          this.contentVersion = contentVersion;
          return this;
        }

        /** The requested scale for the image. */
        @com.google.api.client.util.Key
        private Integer scale;

        /** The requested scale for the image.

       [minimum: 0]
         */
        public Integer getScale() {
          return scale;
        }

        /** The requested scale for the image. */
        public Get setScale(Integer scale) {
          this.scale = scale;
          return this;
        }

        /**
       * The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex:
       * 'en_US'.
       */
        @com.google.api.client.util.Key
        private String locale;

        /** The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'.
         */
        public String getLocale() {
          return locale;
        }

        /**
       * The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex:
       * 'en_US'.
       */
        public Get setLocale(String locale) {
          this.locale = locale;
          return this;
        }

        /**
       * The requested pixel height for any images. If height is provided width must also be
       * provided.
       */
        @com.google.api.client.util.Key
        private Integer h;

        /** The requested pixel height for any images. If height is provided width must also be provided.
         */
        public Integer getH() {
          return h;
        }

        /**
       * The requested pixel height for any images. If height is provided width must also be
       * provided.
       */
        public Get setH(Integer h) {
          this.h = h;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public Get setSource(String source) {
          this.source = source;
          return this;
        }

        /**
       * The requested pixel width for any images. If width is provided height must also be
       * provided.
       */
        @com.google.api.client.util.Key
        private Integer w;

        /** The requested pixel width for any images. If width is provided height must also be provided.
         */
        public Integer getW() {
          return w;
        }

        /**
       * The requested pixel width for any images. If width is provided height must also be
       * provided.
       */
        public Get setW(Integer w) {
          this.w = w;
          return this;
        }

      }
      /**
       * Gets the annotation data for a volume and layer.
       *
       * Create a request for the method "annotationData.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param volumeId The volume to retrieve annotation data for.
       * @param layerId The ID for the layer to get the annotation data.
       * @param contentVersion The content version for the requested volume.
       * @return the request
       */
      public List list(String volumeId, String layerId, String contentVersion) throws java.io.IOException {
        List result = new List(volumeId, layerId, contentVersion);
        initialize(result);
        return result;
      }

      public class List extends BooksRequest<com.google.api.services.books.model.Annotationsdata> {

        private static final String REST_PATH = "volumes/{volumeId}/layers/{layerId}/data";

        /**
         * Gets the annotation data for a volume and layer.
         *
         * Create a request for the method "annotationData.list".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param volumeId The volume to retrieve annotation data for.
         * @param layerId The ID for the layer to get the annotation data.
         * @param contentVersion The content version for the requested volume.
         * @since 1.13
         */
        protected List(String volumeId, String layerId, String contentVersion) {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Annotationsdata.class);
          this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
          this.layerId = Preconditions.checkNotNull(layerId, "Required parameter layerId must be specified.");
          this.contentVersion = Preconditions.checkNotNull(contentVersion, "Required parameter contentVersion must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** The volume to retrieve annotation data for. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** The volume to retrieve annotation data for.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** The volume to retrieve annotation data for. */
        public List setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /** The ID for the layer to get the annotation data. */
        @com.google.api.client.util.Key
        private String layerId;

        /** The ID for the layer to get the annotation data.
         */
        public String getLayerId() {
          return layerId;
        }

        /** The ID for the layer to get the annotation data. */
        public List setLayerId(String layerId) {
          this.layerId = layerId;
          return this;
        }

        /** The content version for the requested volume. */
        @com.google.api.client.util.Key
        private String contentVersion;

        /** The content version for the requested volume.
         */
        public String getContentVersion() {
          return contentVersion;
        }

        /** The content version for the requested volume. */
        public List setContentVersion(String contentVersion) {
          this.contentVersion = contentVersion;
          return this;
        }

        /** The requested scale for the image. */
        @com.google.api.client.util.Key
        private Integer scale;

        /** The requested scale for the image.

       [minimum: 0]
         */
        public Integer getScale() {
          return scale;
        }

        /** The requested scale for the image. */
        public List setScale(Integer scale) {
          this.scale = scale;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public List setSource(String source) {
          this.source = source;
          return this;
        }

        /**
       * The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex:
       * 'en_US'.
       */
        @com.google.api.client.util.Key
        private String locale;

        /** The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'.
         */
        public String getLocale() {
          return locale;
        }

        /**
       * The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex:
       * 'en_US'.
       */
        public List setLocale(String locale) {
          this.locale = locale;
          return this;
        }

        /**
       * The requested pixel height for any images. If height is provided width must also be
       * provided.
       */
        @com.google.api.client.util.Key
        private Integer h;

        /** The requested pixel height for any images. If height is provided width must also be provided.
         */
        public Integer getH() {
          return h;
        }

        /**
       * The requested pixel height for any images. If height is provided width must also be
       * provided.
       */
        public List setH(Integer h) {
          this.h = h;
          return this;
        }

        /** RFC 3339 timestamp to restrict to items updated prior to this timestamp (exclusive). */
        @com.google.api.client.util.Key
        private String updatedMax;

        /** RFC 3339 timestamp to restrict to items updated prior to this timestamp (exclusive).
         */
        public String getUpdatedMax() {
          return updatedMax;
        }

        /** RFC 3339 timestamp to restrict to items updated prior to this timestamp (exclusive). */
        public List setUpdatedMax(String updatedMax) {
          this.updatedMax = updatedMax;
          return this;
        }

        /** Maximum number of results to return */
        @com.google.api.client.util.Key
        private Long maxResults;

        /** Maximum number of results to return

       [minimum: 0] [maximum: 200]
         */
        public Long getMaxResults() {
          return maxResults;
        }

        /** Maximum number of results to return */
        public List setMaxResults(Long maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        /** The list of Annotation Data Ids to retrieve. Pagination is ignored if this is set. */
        @com.google.api.client.util.Key
        private java.util.List<String> annotationDataId;

        /** The list of Annotation Data Ids to retrieve. Pagination is ignored if this is set.
         */
        public java.util.List<String> getAnnotationDataId() {
          return annotationDataId;
        }

        /** The list of Annotation Data Ids to retrieve. Pagination is ignored if this is set. */
        public List setAnnotationDataId(java.util.List<String> annotationDataId) {
          this.annotationDataId = annotationDataId;
          return this;
        }

        /** The value of the nextToken from the previous page. */
        @com.google.api.client.util.Key
        private String pageToken;

        /** The value of the nextToken from the previous page.
         */
        public String getPageToken() {
          return pageToken;
        }

        /** The value of the nextToken from the previous page. */
        public List setPageToken(String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /**
       * The requested pixel width for any images. If width is provided height must also be
       * provided.
       */
        @com.google.api.client.util.Key
        private Integer w;

        /** The requested pixel width for any images. If width is provided height must also be provided.
         */
        public Integer getW() {
          return w;
        }

        /**
       * The requested pixel width for any images. If width is provided height must also be
       * provided.
       */
        public List setW(Integer w) {
          this.w = w;
          return this;
        }

        /** RFC 3339 timestamp to restrict to items updated since this timestamp (inclusive). */
        @com.google.api.client.util.Key
        private String updatedMin;

        /** RFC 3339 timestamp to restrict to items updated since this timestamp (inclusive).
         */
        public String getUpdatedMin() {
          return updatedMin;
        }

        /** RFC 3339 timestamp to restrict to items updated since this timestamp (inclusive). */
        public List setUpdatedMin(String updatedMin) {
          this.updatedMin = updatedMin;
          return this;
        }

      }

    }
    /**
     * An accessor for creating requests from the VolumeAnnotations collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Books books = new Books(...);}
     *   {@code Books.VolumeAnnotations.List request = books.volumeAnnotations().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public VolumeAnnotations volumeAnnotations() {
      return new VolumeAnnotations();
    }

    /**
     * The "volumeAnnotations" collection of methods.
     */
    public class VolumeAnnotations {

      /**
       * Gets the volume annotation.
       *
       * Create a request for the method "volumeAnnotations.get".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param volumeId The volume to retrieve annotations for.
       * @param layerId The ID for the layer to get the annotations.
       * @param annotationId The ID of the volume annotation to retrieve.
       * @return the request
       */
      public Get get(String volumeId, String layerId, String annotationId) throws java.io.IOException {
        Get result = new Get(volumeId, layerId, annotationId);
        initialize(result);
        return result;
      }

      public class Get extends BooksRequest<com.google.api.services.books.model.Volumeannotation> {

        private static final String REST_PATH = "volumes/{volumeId}/layers/{layerId}/annotations/{annotationId}";

        /**
         * Gets the volume annotation.
         *
         * Create a request for the method "volumeAnnotations.get".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
         * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param volumeId The volume to retrieve annotations for.
         * @param layerId The ID for the layer to get the annotations.
         * @param annotationId The ID of the volume annotation to retrieve.
         * @since 1.13
         */
        protected Get(String volumeId, String layerId, String annotationId) {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Volumeannotation.class);
          this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
          this.layerId = Preconditions.checkNotNull(layerId, "Required parameter layerId must be specified.");
          this.annotationId = Preconditions.checkNotNull(annotationId, "Required parameter annotationId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get setAlt(String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setFields(String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUserIp(String userIp) {
          return (Get) super.setUserIp(userIp);
        }

        /** The volume to retrieve annotations for. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** The volume to retrieve annotations for.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** The volume to retrieve annotations for. */
        public Get setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /** The ID for the layer to get the annotations. */
        @com.google.api.client.util.Key
        private String layerId;

        /** The ID for the layer to get the annotations.
         */
        public String getLayerId() {
          return layerId;
        }

        /** The ID for the layer to get the annotations. */
        public Get setLayerId(String layerId) {
          this.layerId = layerId;
          return this;
        }

        /** The ID of the volume annotation to retrieve. */
        @com.google.api.client.util.Key
        private String annotationId;

        /** The ID of the volume annotation to retrieve.
         */
        public String getAnnotationId() {
          return annotationId;
        }

        /** The ID of the volume annotation to retrieve. */
        public Get setAnnotationId(String annotationId) {
          this.annotationId = annotationId;
          return this;
        }

        /**
       * The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex:
       * 'en_US'.
       */
        @com.google.api.client.util.Key
        private String locale;

        /** The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'.
         */
        public String getLocale() {
          return locale;
        }

        /**
       * The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex:
       * 'en_US'.
       */
        public Get setLocale(String locale) {
          this.locale = locale;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public Get setSource(String source) {
          this.source = source;
          return this;
        }

      }
      /**
       * Gets the volume annotations for a volume and layer.
       *
       * Create a request for the method "volumeAnnotations.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param volumeId The volume to retrieve annotations for.
       * @param layerId The ID for the layer to get the annotations.
       * @param contentVersion The content version for the requested volume.
       * @return the request
       */
      public List list(String volumeId, String layerId, String contentVersion) throws java.io.IOException {
        List result = new List(volumeId, layerId, contentVersion);
        initialize(result);
        return result;
      }

      public class List extends BooksRequest<com.google.api.services.books.model.Volumeannotations> {

        private static final String REST_PATH = "volumes/{volumeId}/layers/{layerId}";

        /**
         * Gets the volume annotations for a volume and layer.
         *
         * Create a request for the method "volumeAnnotations.list".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param volumeId The volume to retrieve annotations for.
         * @param layerId The ID for the layer to get the annotations.
         * @param contentVersion The content version for the requested volume.
         * @since 1.13
         */
        protected List(String volumeId, String layerId, String contentVersion) {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Volumeannotations.class);
          this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
          this.layerId = Preconditions.checkNotNull(layerId, "Required parameter layerId must be specified.");
          this.contentVersion = Preconditions.checkNotNull(contentVersion, "Required parameter contentVersion must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** The volume to retrieve annotations for. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** The volume to retrieve annotations for.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** The volume to retrieve annotations for. */
        public List setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /** The ID for the layer to get the annotations. */
        @com.google.api.client.util.Key
        private String layerId;

        /** The ID for the layer to get the annotations.
         */
        public String getLayerId() {
          return layerId;
        }

        /** The ID for the layer to get the annotations. */
        public List setLayerId(String layerId) {
          this.layerId = layerId;
          return this;
        }

        /** The content version for the requested volume. */
        @com.google.api.client.util.Key
        private String contentVersion;

        /** The content version for the requested volume.
         */
        public String getContentVersion() {
          return contentVersion;
        }

        /** The content version for the requested volume. */
        public List setContentVersion(String contentVersion) {
          this.contentVersion = contentVersion;
          return this;
        }

        /**
       * Set to true to return deleted annotations. updatedMin must be in the request to use this.
       * Defaults to false.
       */
        @com.google.api.client.util.Key
        private Boolean showDeleted;

        /** Set to true to return deleted annotations. updatedMin must be in the request to use this. Defaults
       to false.
         */
        public Boolean getShowDeleted() {
          return showDeleted;
        }

        /**
       * Set to true to return deleted annotations. updatedMin must be in the request to use this.
       * Defaults to false.
       */
        public List setShowDeleted(Boolean showDeleted) {
          this.showDeleted = showDeleted;
          return this;
        }

        /** The version of the volume annotations that you are requesting. */
        @com.google.api.client.util.Key
        private String volumeAnnotationsVersion;

        /** The version of the volume annotations that you are requesting.
         */
        public String getVolumeAnnotationsVersion() {
          return volumeAnnotationsVersion;
        }

        /** The version of the volume annotations that you are requesting. */
        public List setVolumeAnnotationsVersion(String volumeAnnotationsVersion) {
          this.volumeAnnotationsVersion = volumeAnnotationsVersion;
          return this;
        }

        /** The end position to end retrieving data from. */
        @com.google.api.client.util.Key
        private String endPosition;

        /** The end position to end retrieving data from.
         */
        public String getEndPosition() {
          return endPosition;
        }

        /** The end position to end retrieving data from. */
        public List setEndPosition(String endPosition) {
          this.endPosition = endPosition;
          return this;
        }

        /** The end offset to end retrieving data from. */
        @com.google.api.client.util.Key
        private String endOffset;

        /** The end offset to end retrieving data from.
         */
        public String getEndOffset() {
          return endOffset;
        }

        /** The end offset to end retrieving data from. */
        public List setEndOffset(String endOffset) {
          this.endOffset = endOffset;
          return this;
        }

        /**
       * The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex:
       * 'en_US'.
       */
        @com.google.api.client.util.Key
        private String locale;

        /** The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'.
         */
        public String getLocale() {
          return locale;
        }

        /**
       * The locale information for the data. ISO-639-1 language and ISO-3166-1 country code. Ex:
       * 'en_US'.
       */
        public List setLocale(String locale) {
          this.locale = locale;
          return this;
        }

        /** RFC 3339 timestamp to restrict to items updated since this timestamp (inclusive). */
        @com.google.api.client.util.Key
        private String updatedMin;

        /** RFC 3339 timestamp to restrict to items updated since this timestamp (inclusive).
         */
        public String getUpdatedMin() {
          return updatedMin;
        }

        /** RFC 3339 timestamp to restrict to items updated since this timestamp (inclusive). */
        public List setUpdatedMin(String updatedMin) {
          this.updatedMin = updatedMin;
          return this;
        }

        /** RFC 3339 timestamp to restrict to items updated prior to this timestamp (exclusive). */
        @com.google.api.client.util.Key
        private String updatedMax;

        /** RFC 3339 timestamp to restrict to items updated prior to this timestamp (exclusive).
         */
        public String getUpdatedMax() {
          return updatedMax;
        }

        /** RFC 3339 timestamp to restrict to items updated prior to this timestamp (exclusive). */
        public List setUpdatedMax(String updatedMax) {
          this.updatedMax = updatedMax;
          return this;
        }

        /** Maximum number of results to return */
        @com.google.api.client.util.Key
        private Long maxResults;

        /** Maximum number of results to return

       [minimum: 0] [maximum: 200]
         */
        public Long getMaxResults() {
          return maxResults;
        }

        /** Maximum number of results to return */
        public List setMaxResults(Long maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        /** The value of the nextToken from the previous page. */
        @com.google.api.client.util.Key
        private String pageToken;

        /** The value of the nextToken from the previous page.
         */
        public String getPageToken() {
          return pageToken;
        }

        /** The value of the nextToken from the previous page. */
        public List setPageToken(String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public List setSource(String source) {
          this.source = source;
          return this;
        }

        /** The start offset to start retrieving data from. */
        @com.google.api.client.util.Key
        private String startOffset;

        /** The start offset to start retrieving data from.
         */
        public String getStartOffset() {
          return startOffset;
        }

        /** The start offset to start retrieving data from. */
        public List setStartOffset(String startOffset) {
          this.startOffset = startOffset;
          return this;
        }

        /** The start position to start retrieving data from. */
        @com.google.api.client.util.Key
        private String startPosition;

        /** The start position to start retrieving data from.
         */
        public String getStartPosition() {
          return startPosition;
        }

        /** The start position to start retrieving data from. */
        public List setStartPosition(String startPosition) {
          this.startPosition = startPosition;
          return this;
        }

      }

    }
  }

  /**
   * An accessor for creating requests from the Myconfig collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Books books = new Books(...);}
   *   {@code Books.Myconfig.List request = books.myconfig().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Myconfig myconfig() {
    return new Myconfig();
  }

  /**
   * The "myconfig" collection of methods.
   */
  public class Myconfig {

    /**
     * Release downloaded content access restriction.
     *
     * Create a request for the method "myconfig.releaseDownloadAccess".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link ReleaseDownloadAccess#execute()} method to invoke the remote
     * operation.
     *
     * @param volumeIds The volume(s) to release restrictions for.
     * @param cpksver The device/version ID from which to release the restriction.
     * @return the request
     */
    public ReleaseDownloadAccess releaseDownloadAccess(java.util.List<String> volumeIds, String cpksver) throws java.io.IOException {
      ReleaseDownloadAccess result = new ReleaseDownloadAccess(volumeIds, cpksver);
      initialize(result);
      return result;
    }

    public class ReleaseDownloadAccess extends BooksRequest<com.google.api.services.books.model.DownloadAccesses> {

      private static final String REST_PATH = "myconfig/releaseDownloadAccess";

      /**
       * Release downloaded content access restriction.
       *
       * Create a request for the method "myconfig.releaseDownloadAccess".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link ReleaseDownloadAccess#execute()} method to invoke the remote
       * operation. <p> {@link ReleaseDownloadAccess#initialize(AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param volumeIds The volume(s) to release restrictions for.
       * @param cpksver The device/version ID from which to release the restriction.
       * @since 1.13
       */
      protected ReleaseDownloadAccess(java.util.List<String> volumeIds, String cpksver) {
        super(Books.this, "POST", REST_PATH, null, com.google.api.services.books.model.DownloadAccesses.class);
        this.volumeIds = Preconditions.checkNotNull(volumeIds, "Required parameter volumeIds must be specified.");
        this.cpksver = Preconditions.checkNotNull(cpksver, "Required parameter cpksver must be specified.");
      }

      @Override
      public ReleaseDownloadAccess setAlt(String alt) {
        return (ReleaseDownloadAccess) super.setAlt(alt);
      }

      @Override
      public ReleaseDownloadAccess setFields(String fields) {
        return (ReleaseDownloadAccess) super.setFields(fields);
      }

      @Override
      public ReleaseDownloadAccess setKey(String key) {
        return (ReleaseDownloadAccess) super.setKey(key);
      }

      @Override
      public ReleaseDownloadAccess setOauthToken(String oauthToken) {
        return (ReleaseDownloadAccess) super.setOauthToken(oauthToken);
      }

      @Override
      public ReleaseDownloadAccess setPrettyPrint(Boolean prettyPrint) {
        return (ReleaseDownloadAccess) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public ReleaseDownloadAccess setQuotaUser(String quotaUser) {
        return (ReleaseDownloadAccess) super.setQuotaUser(quotaUser);
      }

      @Override
      public ReleaseDownloadAccess setUserIp(String userIp) {
        return (ReleaseDownloadAccess) super.setUserIp(userIp);
      }

      /** The volume(s) to release restrictions for. */
      @com.google.api.client.util.Key
      private java.util.List<String> volumeIds;

      /** The volume(s) to release restrictions for.
       */
      public java.util.List<String> getVolumeIds() {
        return volumeIds;
      }

      /** The volume(s) to release restrictions for. */
      public ReleaseDownloadAccess setVolumeIds(java.util.List<String> volumeIds) {
        this.volumeIds = volumeIds;
        return this;
      }

      /** The device/version ID from which to release the restriction. */
      @com.google.api.client.util.Key
      private String cpksver;

      /** The device/version ID from which to release the restriction.
       */
      public String getCpksver() {
        return cpksver;
      }

      /** The device/version ID from which to release the restriction. */
      public ReleaseDownloadAccess setCpksver(String cpksver) {
        this.cpksver = cpksver;
        return this;
      }

      /** ISO-639-1, ISO-3166-1 codes for message localization, i.e. en_US. */
      @com.google.api.client.util.Key
      private String locale;

      /** ISO-639-1, ISO-3166-1 codes for message localization, i.e. en_US.
       */
      public String getLocale() {
        return locale;
      }

      /** ISO-639-1, ISO-3166-1 codes for message localization, i.e. en_US. */
      public ReleaseDownloadAccess setLocale(String locale) {
        this.locale = locale;
        return this;
      }

      /** String to identify the originator of this request. */
      @com.google.api.client.util.Key
      private String source;

      /** String to identify the originator of this request.
       */
      public String getSource() {
        return source;
      }

      /** String to identify the originator of this request. */
      public ReleaseDownloadAccess setSource(String source) {
        this.source = source;
        return this;
      }

    }
    /**
     * Request concurrent and download access restrictions.
     *
     * Create a request for the method "myconfig.requestAccess".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link RequestAccess#execute()} method to invoke the remote operation.
     *
     * @param source String to identify the originator of this request.
     * @param volumeId The volume to request concurrent/download restrictions for.
     * @param nonce The client nonce value.
     * @param cpksver The device/version ID from which to request the restrictions.
     * @return the request
     */
    public RequestAccess requestAccess(String source, String volumeId, String nonce, String cpksver) throws java.io.IOException {
      RequestAccess result = new RequestAccess(source, volumeId, nonce, cpksver);
      initialize(result);
      return result;
    }

    public class RequestAccess extends BooksRequest<com.google.api.services.books.model.RequestAccess> {

      private static final String REST_PATH = "myconfig/requestAccess";

      /**
       * Request concurrent and download access restrictions.
       *
       * Create a request for the method "myconfig.requestAccess".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link RequestAccess#execute()} method to invoke the remote operation. <p>
       * {@link RequestAccess#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param source String to identify the originator of this request.
       * @param volumeId The volume to request concurrent/download restrictions for.
       * @param nonce The client nonce value.
       * @param cpksver The device/version ID from which to request the restrictions.
       * @since 1.13
       */
      protected RequestAccess(String source, String volumeId, String nonce, String cpksver) {
        super(Books.this, "POST", REST_PATH, null, com.google.api.services.books.model.RequestAccess.class);
        this.source = Preconditions.checkNotNull(source, "Required parameter source must be specified.");
        this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
        this.nonce = Preconditions.checkNotNull(nonce, "Required parameter nonce must be specified.");
        this.cpksver = Preconditions.checkNotNull(cpksver, "Required parameter cpksver must be specified.");
      }

      @Override
      public RequestAccess setAlt(String alt) {
        return (RequestAccess) super.setAlt(alt);
      }

      @Override
      public RequestAccess setFields(String fields) {
        return (RequestAccess) super.setFields(fields);
      }

      @Override
      public RequestAccess setKey(String key) {
        return (RequestAccess) super.setKey(key);
      }

      @Override
      public RequestAccess setOauthToken(String oauthToken) {
        return (RequestAccess) super.setOauthToken(oauthToken);
      }

      @Override
      public RequestAccess setPrettyPrint(Boolean prettyPrint) {
        return (RequestAccess) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public RequestAccess setQuotaUser(String quotaUser) {
        return (RequestAccess) super.setQuotaUser(quotaUser);
      }

      @Override
      public RequestAccess setUserIp(String userIp) {
        return (RequestAccess) super.setUserIp(userIp);
      }

      /** String to identify the originator of this request. */
      @com.google.api.client.util.Key
      private String source;

      /** String to identify the originator of this request.
       */
      public String getSource() {
        return source;
      }

      /** String to identify the originator of this request. */
      public RequestAccess setSource(String source) {
        this.source = source;
        return this;
      }

      /** The volume to request concurrent/download restrictions for. */
      @com.google.api.client.util.Key
      private String volumeId;

      /** The volume to request concurrent/download restrictions for.
       */
      public String getVolumeId() {
        return volumeId;
      }

      /** The volume to request concurrent/download restrictions for. */
      public RequestAccess setVolumeId(String volumeId) {
        this.volumeId = volumeId;
        return this;
      }

      /** The client nonce value. */
      @com.google.api.client.util.Key
      private String nonce;

      /** The client nonce value.
       */
      public String getNonce() {
        return nonce;
      }

      /** The client nonce value. */
      public RequestAccess setNonce(String nonce) {
        this.nonce = nonce;
        return this;
      }

      /** The device/version ID from which to request the restrictions. */
      @com.google.api.client.util.Key
      private String cpksver;

      /** The device/version ID from which to request the restrictions.
       */
      public String getCpksver() {
        return cpksver;
      }

      /** The device/version ID from which to request the restrictions. */
      public RequestAccess setCpksver(String cpksver) {
        this.cpksver = cpksver;
        return this;
      }

      /** ISO-639-1, ISO-3166-1 codes for message localization, i.e. en_US. */
      @com.google.api.client.util.Key
      private String locale;

      /** ISO-639-1, ISO-3166-1 codes for message localization, i.e. en_US.
       */
      public String getLocale() {
        return locale;
      }

      /** ISO-639-1, ISO-3166-1 codes for message localization, i.e. en_US. */
      public RequestAccess setLocale(String locale) {
        this.locale = locale;
        return this;
      }

    }
    /**
     * Request downloaded content access for specified volumes on the My eBooks shelf.
     *
     * Create a request for the method "myconfig.syncVolumeLicenses".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link SyncVolumeLicenses#execute()} method to invoke the remote operation.
     *
     * @param source String to identify the originator of this request.
     * @param nonce The client nonce value.
     * @param cpksver The device/version ID from which to release the restriction.
     * @return the request
     */
    public SyncVolumeLicenses syncVolumeLicenses(String source, String nonce, String cpksver) throws java.io.IOException {
      SyncVolumeLicenses result = new SyncVolumeLicenses(source, nonce, cpksver);
      initialize(result);
      return result;
    }

    public class SyncVolumeLicenses extends BooksRequest<com.google.api.services.books.model.Volumes> {

      private static final String REST_PATH = "myconfig/syncVolumeLicenses";

      /**
       * Request downloaded content access for specified volumes on the My eBooks shelf.
       *
       * Create a request for the method "myconfig.syncVolumeLicenses".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link SyncVolumeLicenses#execute()} method to invoke the remote
       * operation. <p> {@link SyncVolumeLicenses#initialize(AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param source String to identify the originator of this request.
       * @param nonce The client nonce value.
       * @param cpksver The device/version ID from which to release the restriction.
       * @since 1.13
       */
      protected SyncVolumeLicenses(String source, String nonce, String cpksver) {
        super(Books.this, "POST", REST_PATH, null, com.google.api.services.books.model.Volumes.class);
        this.source = Preconditions.checkNotNull(source, "Required parameter source must be specified.");
        this.nonce = Preconditions.checkNotNull(nonce, "Required parameter nonce must be specified.");
        this.cpksver = Preconditions.checkNotNull(cpksver, "Required parameter cpksver must be specified.");
      }

      @Override
      public SyncVolumeLicenses setAlt(String alt) {
        return (SyncVolumeLicenses) super.setAlt(alt);
      }

      @Override
      public SyncVolumeLicenses setFields(String fields) {
        return (SyncVolumeLicenses) super.setFields(fields);
      }

      @Override
      public SyncVolumeLicenses setKey(String key) {
        return (SyncVolumeLicenses) super.setKey(key);
      }

      @Override
      public SyncVolumeLicenses setOauthToken(String oauthToken) {
        return (SyncVolumeLicenses) super.setOauthToken(oauthToken);
      }

      @Override
      public SyncVolumeLicenses setPrettyPrint(Boolean prettyPrint) {
        return (SyncVolumeLicenses) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public SyncVolumeLicenses setQuotaUser(String quotaUser) {
        return (SyncVolumeLicenses) super.setQuotaUser(quotaUser);
      }

      @Override
      public SyncVolumeLicenses setUserIp(String userIp) {
        return (SyncVolumeLicenses) super.setUserIp(userIp);
      }

      /** String to identify the originator of this request. */
      @com.google.api.client.util.Key
      private String source;

      /** String to identify the originator of this request.
       */
      public String getSource() {
        return source;
      }

      /** String to identify the originator of this request. */
      public SyncVolumeLicenses setSource(String source) {
        this.source = source;
        return this;
      }

      /** The client nonce value. */
      @com.google.api.client.util.Key
      private String nonce;

      /** The client nonce value.
       */
      public String getNonce() {
        return nonce;
      }

      /** The client nonce value. */
      public SyncVolumeLicenses setNonce(String nonce) {
        this.nonce = nonce;
        return this;
      }

      /** The device/version ID from which to release the restriction. */
      @com.google.api.client.util.Key
      private String cpksver;

      /** The device/version ID from which to release the restriction.
       */
      public String getCpksver() {
        return cpksver;
      }

      /** The device/version ID from which to release the restriction. */
      public SyncVolumeLicenses setCpksver(String cpksver) {
        this.cpksver = cpksver;
        return this;
      }

      /** ISO-639-1, ISO-3166-1 codes for message localization, i.e. en_US. */
      @com.google.api.client.util.Key
      private String locale;

      /** ISO-639-1, ISO-3166-1 codes for message localization, i.e. en_US.
       */
      public String getLocale() {
        return locale;
      }

      /** ISO-639-1, ISO-3166-1 codes for message localization, i.e. en_US. */
      public SyncVolumeLicenses setLocale(String locale) {
        this.locale = locale;
        return this;
      }

      /** Set to true to show pre-ordered books. Defaults to false. */
      @com.google.api.client.util.Key
      private Boolean showPreorders;

      /** Set to true to show pre-ordered books. Defaults to false.
       */
      public Boolean getShowPreorders() {
        return showPreorders;
      }

      /** Set to true to show pre-ordered books. Defaults to false. */
      public SyncVolumeLicenses setShowPreorders(Boolean showPreorders) {
        this.showPreorders = showPreorders;
        return this;
      }

      /** The volume(s) to request download restrictions for. */
      @com.google.api.client.util.Key
      private java.util.List<String> volumeIds;

      /** The volume(s) to request download restrictions for.
       */
      public java.util.List<String> getVolumeIds() {
        return volumeIds;
      }

      /** The volume(s) to request download restrictions for. */
      public SyncVolumeLicenses setVolumeIds(java.util.List<String> volumeIds) {
        this.volumeIds = volumeIds;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Mylibrary collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Books books = new Books(...);}
   *   {@code Books.Mylibrary.List request = books.mylibrary().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Mylibrary mylibrary() {
    return new Mylibrary();
  }

  /**
   * The "mylibrary" collection of methods.
   */
  public class Mylibrary {

    /**
     * An accessor for creating requests from the Annotations collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Books books = new Books(...);}
     *   {@code Books.Annotations.List request = books.annotations().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Annotations annotations() {
      return new Annotations();
    }

    /**
     * The "annotations" collection of methods.
     */
    public class Annotations {

      /**
       * Deletes an annotation.
       *
       * Create a request for the method "annotations.delete".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       *
       * @param annotationId The ID for the annotation to delete.
       * @return the request
       */
      public Delete delete(String annotationId) throws java.io.IOException {
        Delete result = new Delete(annotationId);
        initialize(result);
        return result;
      }

      public class Delete extends BooksRequest<Void> {

        private static final String REST_PATH = "mylibrary/annotations/{annotationId}";

        /**
         * Deletes an annotation.
         *
         * Create a request for the method "annotations.delete".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link Delete#execute()} method to invoke the remote operation. <p> {@link
         * Delete#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param annotationId The ID for the annotation to delete.
         * @since 1.13
         */
        protected Delete(String annotationId) {
          super(Books.this, "DELETE", REST_PATH, null, Void.class);
          this.annotationId = Preconditions.checkNotNull(annotationId, "Required parameter annotationId must be specified.");
        }

        @Override
        public Delete setAlt(String alt) {
          return (Delete) super.setAlt(alt);
        }

        @Override
        public Delete setFields(String fields) {
          return (Delete) super.setFields(fields);
        }

        @Override
        public Delete setKey(String key) {
          return (Delete) super.setKey(key);
        }

        @Override
        public Delete setOauthToken(String oauthToken) {
          return (Delete) super.setOauthToken(oauthToken);
        }

        @Override
        public Delete setPrettyPrint(Boolean prettyPrint) {
          return (Delete) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Delete setQuotaUser(String quotaUser) {
          return (Delete) super.setQuotaUser(quotaUser);
        }

        @Override
        public Delete setUserIp(String userIp) {
          return (Delete) super.setUserIp(userIp);
        }

        /** The ID for the annotation to delete. */
        @com.google.api.client.util.Key
        private String annotationId;

        /** The ID for the annotation to delete.
         */
        public String getAnnotationId() {
          return annotationId;
        }

        /** The ID for the annotation to delete. */
        public Delete setAnnotationId(String annotationId) {
          this.annotationId = annotationId;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public Delete setSource(String source) {
          this.source = source;
          return this;
        }

      }
      /**
       * Gets an annotation by its ID.
       *
       * Create a request for the method "annotations.get".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param annotationId The ID for the annotation to retrieve.
       * @return the request
       */
      public Get get(String annotationId) throws java.io.IOException {
        Get result = new Get(annotationId);
        initialize(result);
        return result;
      }

      public class Get extends BooksRequest<com.google.api.services.books.model.Annotation> {

        private static final String REST_PATH = "mylibrary/annotations/{annotationId}";

        /**
         * Gets an annotation by its ID.
         *
         * Create a request for the method "annotations.get".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
         * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param annotationId The ID for the annotation to retrieve.
         * @since 1.13
         */
        protected Get(String annotationId) {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Annotation.class);
          this.annotationId = Preconditions.checkNotNull(annotationId, "Required parameter annotationId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get setAlt(String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setFields(String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUserIp(String userIp) {
          return (Get) super.setUserIp(userIp);
        }

        /** The ID for the annotation to retrieve. */
        @com.google.api.client.util.Key
        private String annotationId;

        /** The ID for the annotation to retrieve.
         */
        public String getAnnotationId() {
          return annotationId;
        }

        /** The ID for the annotation to retrieve. */
        public Get setAnnotationId(String annotationId) {
          this.annotationId = annotationId;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public Get setSource(String source) {
          this.source = source;
          return this;
        }

      }
      /**
       * Inserts a new annotation.
       *
       * Create a request for the method "annotations.insert".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       *
       * @param content the {@link com.google.api.services.books.model.Annotation}
       * @return the request
       */
      public Insert insert(com.google.api.services.books.model.Annotation content) throws java.io.IOException {
        Insert result = new Insert(content);
        initialize(result);
        return result;
      }

      public class Insert extends BooksRequest<com.google.api.services.books.model.Annotation> {

        private static final String REST_PATH = "mylibrary/annotations";

        /**
         * Inserts a new annotation.
         *
         * Create a request for the method "annotations.insert".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link Insert#execute()} method to invoke the remote operation. <p> {@link
         * Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param content the {@link com.google.api.services.books.model.Annotation}
         * @since 1.13
         */
        protected Insert(com.google.api.services.books.model.Annotation content) {
          super(Books.this, "POST", REST_PATH, content, com.google.api.services.books.model.Annotation.class);
        }

        @Override
        public Insert setAlt(String alt) {
          return (Insert) super.setAlt(alt);
        }

        @Override
        public Insert setFields(String fields) {
          return (Insert) super.setFields(fields);
        }

        @Override
        public Insert setKey(String key) {
          return (Insert) super.setKey(key);
        }

        @Override
        public Insert setOauthToken(String oauthToken) {
          return (Insert) super.setOauthToken(oauthToken);
        }

        @Override
        public Insert setPrettyPrint(Boolean prettyPrint) {
          return (Insert) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Insert setQuotaUser(String quotaUser) {
          return (Insert) super.setQuotaUser(quotaUser);
        }

        @Override
        public Insert setUserIp(String userIp) {
          return (Insert) super.setUserIp(userIp);
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public Insert setSource(String source) {
          this.source = source;
          return this;
        }

      }
      /**
       * Retrieves a list of annotations, possibly filtered.
       *
       * Create a request for the method "annotations.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @return the request
       */
      public List list() throws java.io.IOException {
        List result = new List();
        initialize(result);
        return result;
      }

      public class List extends BooksRequest<com.google.api.services.books.model.Annotations> {

        private static final String REST_PATH = "mylibrary/annotations";

        /**
         * Retrieves a list of annotations, possibly filtered.
         *
         * Create a request for the method "annotations.list".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @since 1.13
         */
        protected List() {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Annotations.class);
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /**
       * Set to true to return deleted annotations. updatedMin must be in the request to use this.
       * Defaults to false.
       */
        @com.google.api.client.util.Key
        private Boolean showDeleted;

        /** Set to true to return deleted annotations. updatedMin must be in the request to use this. Defaults
       to false.
         */
        public Boolean getShowDeleted() {
          return showDeleted;
        }

        /**
       * Set to true to return deleted annotations. updatedMin must be in the request to use this.
       * Defaults to false.
       */
        public List setShowDeleted(Boolean showDeleted) {
          this.showDeleted = showDeleted;
          return this;
        }

        /** RFC 3339 timestamp to restrict to items updated since this timestamp (inclusive). */
        @com.google.api.client.util.Key
        private String updatedMin;

        /** RFC 3339 timestamp to restrict to items updated since this timestamp (inclusive).
         */
        public String getUpdatedMin() {
          return updatedMin;
        }

        /** RFC 3339 timestamp to restrict to items updated since this timestamp (inclusive). */
        public List setUpdatedMin(String updatedMin) {
          this.updatedMin = updatedMin;
          return this;
        }

        /** RFC 3339 timestamp to restrict to items updated prior to this timestamp (exclusive). */
        @com.google.api.client.util.Key
        private String updatedMax;

        /** RFC 3339 timestamp to restrict to items updated prior to this timestamp (exclusive).
         */
        public String getUpdatedMax() {
          return updatedMax;
        }

        /** RFC 3339 timestamp to restrict to items updated prior to this timestamp (exclusive). */
        public List setUpdatedMax(String updatedMax) {
          this.updatedMax = updatedMax;
          return this;
        }

        /** The volume to restrict annotations to. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** The volume to restrict annotations to.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** The volume to restrict annotations to. */
        public List setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /** Maximum number of results to return */
        @com.google.api.client.util.Key
        private Long maxResults;

        /** Maximum number of results to return

       [minimum: 0] [maximum: 40]
         */
        public Long getMaxResults() {
          return maxResults;
        }

        /** Maximum number of results to return */
        public List setMaxResults(Long maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        /** The value of the nextToken from the previous page. */
        @com.google.api.client.util.Key
        private String pageToken;

        /** The value of the nextToken from the previous page.
         */
        public String getPageToken() {
          return pageToken;
        }

        /** The value of the nextToken from the previous page. */
        public List setPageToken(String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The page ID(s) for the volume that is being queried. */
        @com.google.api.client.util.Key
        private java.util.List<String> pageIds;

        /** The page ID(s) for the volume that is being queried.
         */
        public java.util.List<String> getPageIds() {
          return pageIds;
        }

        /** The page ID(s) for the volume that is being queried. */
        public List setPageIds(java.util.List<String> pageIds) {
          this.pageIds = pageIds;
          return this;
        }

        /** The content version for the requested volume. */
        @com.google.api.client.util.Key
        private String contentVersion;

        /** The content version for the requested volume.
         */
        public String getContentVersion() {
          return contentVersion;
        }

        /** The content version for the requested volume. */
        public List setContentVersion(String contentVersion) {
          this.contentVersion = contentVersion;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public List setSource(String source) {
          this.source = source;
          return this;
        }

        /** The layer ID to limit annotation by. */
        @com.google.api.client.util.Key
        private String layerId;

        /** The layer ID to limit annotation by.
         */
        public String getLayerId() {
          return layerId;
        }

        /** The layer ID to limit annotation by. */
        public List setLayerId(String layerId) {
          this.layerId = layerId;
          return this;
        }

      }
      /**
       * Updates an existing annotation.
       *
       * Create a request for the method "annotations.update".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Update#execute()} method to invoke the remote operation.
       *
       * @param annotationId The ID for the annotation to update.
       * @param content the {@link com.google.api.services.books.model.Annotation}
       * @return the request
       */
      public Update update(String annotationId, com.google.api.services.books.model.Annotation content) throws java.io.IOException {
        Update result = new Update(annotationId, content);
        initialize(result);
        return result;
      }

      public class Update extends BooksRequest<com.google.api.services.books.model.Annotation> {

        private static final String REST_PATH = "mylibrary/annotations/{annotationId}";

        /**
         * Updates an existing annotation.
         *
         * Create a request for the method "annotations.update".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link Update#execute()} method to invoke the remote operation. <p> {@link
         * Update#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param annotationId The ID for the annotation to update.
         * @param content the {@link com.google.api.services.books.model.Annotation}
         * @since 1.13
         */
        protected Update(String annotationId, com.google.api.services.books.model.Annotation content) {
          super(Books.this, "PUT", REST_PATH, content, com.google.api.services.books.model.Annotation.class);
          this.annotationId = Preconditions.checkNotNull(annotationId, "Required parameter annotationId must be specified.");
        }

        @Override
        public Update setAlt(String alt) {
          return (Update) super.setAlt(alt);
        }

        @Override
        public Update setFields(String fields) {
          return (Update) super.setFields(fields);
        }

        @Override
        public Update setKey(String key) {
          return (Update) super.setKey(key);
        }

        @Override
        public Update setOauthToken(String oauthToken) {
          return (Update) super.setOauthToken(oauthToken);
        }

        @Override
        public Update setPrettyPrint(Boolean prettyPrint) {
          return (Update) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Update setQuotaUser(String quotaUser) {
          return (Update) super.setQuotaUser(quotaUser);
        }

        @Override
        public Update setUserIp(String userIp) {
          return (Update) super.setUserIp(userIp);
        }

        /** The ID for the annotation to update. */
        @com.google.api.client.util.Key
        private String annotationId;

        /** The ID for the annotation to update.
         */
        public String getAnnotationId() {
          return annotationId;
        }

        /** The ID for the annotation to update. */
        public Update setAnnotationId(String annotationId) {
          this.annotationId = annotationId;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public Update setSource(String source) {
          this.source = source;
          return this;
        }

      }

    }
    /**
     * An accessor for creating requests from the Bookshelves collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Books books = new Books(...);}
     *   {@code Books.Bookshelves.List request = books.bookshelves().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Bookshelves bookshelves() {
      return new Bookshelves();
    }

    /**
     * The "bookshelves" collection of methods.
     */
    public class Bookshelves {

      /**
       * Adds a volume to a bookshelf.
       *
       * Create a request for the method "bookshelves.addVolume".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link AddVolume#execute()} method to invoke the remote operation.
       *
       * @param shelf ID of bookshelf to which to add a volume.
       * @param volumeId ID of volume to add.
       * @return the request
       */
      public AddVolume addVolume(String shelf, String volumeId) throws java.io.IOException {
        AddVolume result = new AddVolume(shelf, volumeId);
        initialize(result);
        return result;
      }

      public class AddVolume extends BooksRequest<Void> {

        private static final String REST_PATH = "mylibrary/bookshelves/{shelf}/addVolume";

        /**
         * Adds a volume to a bookshelf.
         *
         * Create a request for the method "bookshelves.addVolume".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link AddVolume#execute()} method to invoke the remote operation. <p>
         * {@link AddVolume#initialize(AbstractGoogleClientRequest)} must be called to initialize this
         * instance immediately after invoking the constructor. </p>
         *
         * @param shelf ID of bookshelf to which to add a volume.
         * @param volumeId ID of volume to add.
         * @since 1.13
         */
        protected AddVolume(String shelf, String volumeId) {
          super(Books.this, "POST", REST_PATH, null, Void.class);
          this.shelf = Preconditions.checkNotNull(shelf, "Required parameter shelf must be specified.");
          this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
        }

        @Override
        public AddVolume setAlt(String alt) {
          return (AddVolume) super.setAlt(alt);
        }

        @Override
        public AddVolume setFields(String fields) {
          return (AddVolume) super.setFields(fields);
        }

        @Override
        public AddVolume setKey(String key) {
          return (AddVolume) super.setKey(key);
        }

        @Override
        public AddVolume setOauthToken(String oauthToken) {
          return (AddVolume) super.setOauthToken(oauthToken);
        }

        @Override
        public AddVolume setPrettyPrint(Boolean prettyPrint) {
          return (AddVolume) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public AddVolume setQuotaUser(String quotaUser) {
          return (AddVolume) super.setQuotaUser(quotaUser);
        }

        @Override
        public AddVolume setUserIp(String userIp) {
          return (AddVolume) super.setUserIp(userIp);
        }

        /** ID of bookshelf to which to add a volume. */
        @com.google.api.client.util.Key
        private String shelf;

        /** ID of bookshelf to which to add a volume.
         */
        public String getShelf() {
          return shelf;
        }

        /** ID of bookshelf to which to add a volume. */
        public AddVolume setShelf(String shelf) {
          this.shelf = shelf;
          return this;
        }

        /** ID of volume to add. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** ID of volume to add.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** ID of volume to add. */
        public AddVolume setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public AddVolume setSource(String source) {
          this.source = source;
          return this;
        }

      }
      /**
       * Clears all volumes from a bookshelf.
       *
       * Create a request for the method "bookshelves.clearVolumes".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link ClearVolumes#execute()} method to invoke the remote operation.
       *
       * @param shelf ID of bookshelf from which to remove a volume.
       * @return the request
       */
      public ClearVolumes clearVolumes(String shelf) throws java.io.IOException {
        ClearVolumes result = new ClearVolumes(shelf);
        initialize(result);
        return result;
      }

      public class ClearVolumes extends BooksRequest<Void> {

        private static final String REST_PATH = "mylibrary/bookshelves/{shelf}/clearVolumes";

        /**
         * Clears all volumes from a bookshelf.
         *
         * Create a request for the method "bookshelves.clearVolumes".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link ClearVolumes#execute()} method to invoke the remote operation. <p>
         * {@link ClearVolumes#initialize(AbstractGoogleClientRequest)} must be called to initialize this
         * instance immediately after invoking the constructor. </p>
         *
         * @param shelf ID of bookshelf from which to remove a volume.
         * @since 1.13
         */
        protected ClearVolumes(String shelf) {
          super(Books.this, "POST", REST_PATH, null, Void.class);
          this.shelf = Preconditions.checkNotNull(shelf, "Required parameter shelf must be specified.");
        }

        @Override
        public ClearVolumes setAlt(String alt) {
          return (ClearVolumes) super.setAlt(alt);
        }

        @Override
        public ClearVolumes setFields(String fields) {
          return (ClearVolumes) super.setFields(fields);
        }

        @Override
        public ClearVolumes setKey(String key) {
          return (ClearVolumes) super.setKey(key);
        }

        @Override
        public ClearVolumes setOauthToken(String oauthToken) {
          return (ClearVolumes) super.setOauthToken(oauthToken);
        }

        @Override
        public ClearVolumes setPrettyPrint(Boolean prettyPrint) {
          return (ClearVolumes) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public ClearVolumes setQuotaUser(String quotaUser) {
          return (ClearVolumes) super.setQuotaUser(quotaUser);
        }

        @Override
        public ClearVolumes setUserIp(String userIp) {
          return (ClearVolumes) super.setUserIp(userIp);
        }

        /** ID of bookshelf from which to remove a volume. */
        @com.google.api.client.util.Key
        private String shelf;

        /** ID of bookshelf from which to remove a volume.
         */
        public String getShelf() {
          return shelf;
        }

        /** ID of bookshelf from which to remove a volume. */
        public ClearVolumes setShelf(String shelf) {
          this.shelf = shelf;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public ClearVolumes setSource(String source) {
          this.source = source;
          return this;
        }

      }
      /**
       * Retrieves metadata for a specific bookshelf belonging to the authenticated user.
       *
       * Create a request for the method "bookshelves.get".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param shelf ID of bookshelf to retrieve.
       * @return the request
       */
      public Get get(String shelf) throws java.io.IOException {
        Get result = new Get(shelf);
        initialize(result);
        return result;
      }

      public class Get extends BooksRequest<com.google.api.services.books.model.Bookshelf> {

        private static final String REST_PATH = "mylibrary/bookshelves/{shelf}";

        /**
         * Retrieves metadata for a specific bookshelf belonging to the authenticated user.
         *
         * Create a request for the method "bookshelves.get".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
         * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param shelf ID of bookshelf to retrieve.
         * @since 1.13
         */
        protected Get(String shelf) {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Bookshelf.class);
          this.shelf = Preconditions.checkNotNull(shelf, "Required parameter shelf must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get setAlt(String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setFields(String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUserIp(String userIp) {
          return (Get) super.setUserIp(userIp);
        }

        /** ID of bookshelf to retrieve. */
        @com.google.api.client.util.Key
        private String shelf;

        /** ID of bookshelf to retrieve.
         */
        public String getShelf() {
          return shelf;
        }

        /** ID of bookshelf to retrieve. */
        public Get setShelf(String shelf) {
          this.shelf = shelf;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public Get setSource(String source) {
          this.source = source;
          return this;
        }

      }
      /**
       * Retrieves a list of bookshelves belonging to the authenticated user.
       *
       * Create a request for the method "bookshelves.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @return the request
       */
      public List list() throws java.io.IOException {
        List result = new List();
        initialize(result);
        return result;
      }

      public class List extends BooksRequest<com.google.api.services.books.model.Bookshelves> {

        private static final String REST_PATH = "mylibrary/bookshelves";

        /**
         * Retrieves a list of bookshelves belonging to the authenticated user.
         *
         * Create a request for the method "bookshelves.list".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @since 1.13
         */
        protected List() {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Bookshelves.class);
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public List setSource(String source) {
          this.source = source;
          return this;
        }

      }
      /**
       * Moves a volume within a bookshelf.
       *
       * Create a request for the method "bookshelves.moveVolume".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link MoveVolume#execute()} method to invoke the remote operation.
       *
       * @param shelf ID of bookshelf with the volume.
       * @param volumeId ID of volume to move.
       * @param volumePosition Position on shelf to move the item (0 puts the item before the current first item, 1 puts it between
       *        the first and the second and so on.)
       * @return the request
       */
      public MoveVolume moveVolume(String shelf, String volumeId, Integer volumePosition) throws java.io.IOException {
        MoveVolume result = new MoveVolume(shelf, volumeId, volumePosition);
        initialize(result);
        return result;
      }

      public class MoveVolume extends BooksRequest<Void> {

        private static final String REST_PATH = "mylibrary/bookshelves/{shelf}/moveVolume";

        /**
         * Moves a volume within a bookshelf.
         *
         * Create a request for the method "bookshelves.moveVolume".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link MoveVolume#execute()} method to invoke the remote operation. <p>
         * {@link MoveVolume#initialize(AbstractGoogleClientRequest)} must be called to initialize this
         * instance immediately after invoking the constructor. </p>
         *
         * @param shelf ID of bookshelf with the volume.
         * @param volumeId ID of volume to move.
         * @param volumePosition Position on shelf to move the item (0 puts the item before the current first item, 1 puts it between
       *        the first and the second and so on.)
         * @since 1.13
         */
        protected MoveVolume(String shelf, String volumeId, Integer volumePosition) {
          super(Books.this, "POST", REST_PATH, null, Void.class);
          this.shelf = Preconditions.checkNotNull(shelf, "Required parameter shelf must be specified.");
          this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
          this.volumePosition = Preconditions.checkNotNull(volumePosition, "Required parameter volumePosition must be specified.");
        }

        @Override
        public MoveVolume setAlt(String alt) {
          return (MoveVolume) super.setAlt(alt);
        }

        @Override
        public MoveVolume setFields(String fields) {
          return (MoveVolume) super.setFields(fields);
        }

        @Override
        public MoveVolume setKey(String key) {
          return (MoveVolume) super.setKey(key);
        }

        @Override
        public MoveVolume setOauthToken(String oauthToken) {
          return (MoveVolume) super.setOauthToken(oauthToken);
        }

        @Override
        public MoveVolume setPrettyPrint(Boolean prettyPrint) {
          return (MoveVolume) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public MoveVolume setQuotaUser(String quotaUser) {
          return (MoveVolume) super.setQuotaUser(quotaUser);
        }

        @Override
        public MoveVolume setUserIp(String userIp) {
          return (MoveVolume) super.setUserIp(userIp);
        }

        /** ID of bookshelf with the volume. */
        @com.google.api.client.util.Key
        private String shelf;

        /** ID of bookshelf with the volume.
         */
        public String getShelf() {
          return shelf;
        }

        /** ID of bookshelf with the volume. */
        public MoveVolume setShelf(String shelf) {
          this.shelf = shelf;
          return this;
        }

        /** ID of volume to move. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** ID of volume to move.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** ID of volume to move. */
        public MoveVolume setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /**
       * Position on shelf to move the item (0 puts the item before the current first item, 1 puts
       * it between the first and the second and so on.)
       */
        @com.google.api.client.util.Key
        private Integer volumePosition;

        /** Position on shelf to move the item (0 puts the item before the current first item, 1 puts it
       between the first and the second and so on.)
         */
        public Integer getVolumePosition() {
          return volumePosition;
        }

        /**
       * Position on shelf to move the item (0 puts the item before the current first item, 1 puts
       * it between the first and the second and so on.)
       */
        public MoveVolume setVolumePosition(Integer volumePosition) {
          this.volumePosition = volumePosition;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public MoveVolume setSource(String source) {
          this.source = source;
          return this;
        }

      }
      /**
       * Removes a volume from a bookshelf.
       *
       * Create a request for the method "bookshelves.removeVolume".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link RemoveVolume#execute()} method to invoke the remote operation.
       *
       * @param shelf ID of bookshelf from which to remove a volume.
       * @param volumeId ID of volume to remove.
       * @return the request
       */
      public RemoveVolume removeVolume(String shelf, String volumeId) throws java.io.IOException {
        RemoveVolume result = new RemoveVolume(shelf, volumeId);
        initialize(result);
        return result;
      }

      public class RemoveVolume extends BooksRequest<Void> {

        private static final String REST_PATH = "mylibrary/bookshelves/{shelf}/removeVolume";

        /**
         * Removes a volume from a bookshelf.
         *
         * Create a request for the method "bookshelves.removeVolume".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link RemoveVolume#execute()} method to invoke the remote operation. <p>
         * {@link RemoveVolume#initialize(AbstractGoogleClientRequest)} must be called to initialize this
         * instance immediately after invoking the constructor. </p>
         *
         * @param shelf ID of bookshelf from which to remove a volume.
         * @param volumeId ID of volume to remove.
         * @since 1.13
         */
        protected RemoveVolume(String shelf, String volumeId) {
          super(Books.this, "POST", REST_PATH, null, Void.class);
          this.shelf = Preconditions.checkNotNull(shelf, "Required parameter shelf must be specified.");
          this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
        }

        @Override
        public RemoveVolume setAlt(String alt) {
          return (RemoveVolume) super.setAlt(alt);
        }

        @Override
        public RemoveVolume setFields(String fields) {
          return (RemoveVolume) super.setFields(fields);
        }

        @Override
        public RemoveVolume setKey(String key) {
          return (RemoveVolume) super.setKey(key);
        }

        @Override
        public RemoveVolume setOauthToken(String oauthToken) {
          return (RemoveVolume) super.setOauthToken(oauthToken);
        }

        @Override
        public RemoveVolume setPrettyPrint(Boolean prettyPrint) {
          return (RemoveVolume) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public RemoveVolume setQuotaUser(String quotaUser) {
          return (RemoveVolume) super.setQuotaUser(quotaUser);
        }

        @Override
        public RemoveVolume setUserIp(String userIp) {
          return (RemoveVolume) super.setUserIp(userIp);
        }

        /** ID of bookshelf from which to remove a volume. */
        @com.google.api.client.util.Key
        private String shelf;

        /** ID of bookshelf from which to remove a volume.
         */
        public String getShelf() {
          return shelf;
        }

        /** ID of bookshelf from which to remove a volume. */
        public RemoveVolume setShelf(String shelf) {
          this.shelf = shelf;
          return this;
        }

        /** ID of volume to remove. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** ID of volume to remove.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** ID of volume to remove. */
        public RemoveVolume setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public RemoveVolume setSource(String source) {
          this.source = source;
          return this;
        }

      }

      /**
       * An accessor for creating requests from the Volumes collection.
       *
       * <p>The typical use is:</p>
       * <pre>
       *   {@code Books books = new Books(...);}
       *   {@code Books.Volumes.List request = books.volumes().list(parameters ...)}
       * </pre>
       *
       * @return the resource collection
       */
      public Volumes volumes() {
        return new Volumes();
      }

      /**
       * The "volumes" collection of methods.
       */
      public class Volumes {

        /**
         * Gets volume information for volumes on a bookshelf.
         *
         * Create a request for the method "volumes.list".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation.
         *
         * @param shelf The bookshelf ID or name retrieve volumes for.
         * @return the request
         */
        public List list(String shelf) throws java.io.IOException {
          List result = new List(shelf);
          initialize(result);
          return result;
        }

        public class List extends BooksRequest<com.google.api.services.books.model.Volumes> {

          private static final String REST_PATH = "mylibrary/bookshelves/{shelf}/volumes";

          /**
           * Gets volume information for volumes on a bookshelf.
           *
           * Create a request for the method "volumes.list".
           *
           * This request holds the parameters needed by the the books server.  After setting any optional
           * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
           * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
           * immediately after invoking the constructor. </p>
           *
           * @param shelf The bookshelf ID or name retrieve volumes for.
           * @since 1.13
           */
          protected List(String shelf) {
            super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Volumes.class);
            this.shelf = Preconditions.checkNotNull(shelf, "Required parameter shelf must be specified.");
          }

          @Override
          public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
            return super.executeUsingHead();
          }

          @Override
          public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
            return super.buildHttpRequestUsingHead();
          }

          @Override
          public List setAlt(String alt) {
            return (List) super.setAlt(alt);
          }

          @Override
          public List setFields(String fields) {
            return (List) super.setFields(fields);
          }

          @Override
          public List setKey(String key) {
            return (List) super.setKey(key);
          }

          @Override
          public List setOauthToken(String oauthToken) {
            return (List) super.setOauthToken(oauthToken);
          }

          @Override
          public List setPrettyPrint(Boolean prettyPrint) {
            return (List) super.setPrettyPrint(prettyPrint);
          }

          @Override
          public List setQuotaUser(String quotaUser) {
            return (List) super.setQuotaUser(quotaUser);
          }

          @Override
          public List setUserIp(String userIp) {
            return (List) super.setUserIp(userIp);
          }

          /** The bookshelf ID or name retrieve volumes for. */
          @com.google.api.client.util.Key
          private String shelf;

          /** The bookshelf ID or name retrieve volumes for.
           */
          public String getShelf() {
            return shelf;
          }

          /** The bookshelf ID or name retrieve volumes for. */
          public List setShelf(String shelf) {
            this.shelf = shelf;
            return this;
          }

          /** Restrict information returned to a set of selected fields. */
          @com.google.api.client.util.Key
          private String projection;

          /** Restrict information returned to a set of selected fields.
           */
          public String getProjection() {
            return projection;
          }

          /** Restrict information returned to a set of selected fields. */
          public List setProjection(String projection) {
            this.projection = projection;
            return this;
          }

          /** ISO-3166-1 code to override the IP-based location. */
          @com.google.api.client.util.Key
          private String country;

          /** ISO-3166-1 code to override the IP-based location.
           */
          public String getCountry() {
            return country;
          }

          /** ISO-3166-1 code to override the IP-based location. */
          public List setCountry(String country) {
            this.country = country;
            return this;
          }

          /** Set to true to show pre-ordered books. Defaults to false. */
          @com.google.api.client.util.Key
          private Boolean showPreorders;

          /** Set to true to show pre-ordered books. Defaults to false.
           */
          public Boolean getShowPreorders() {
            return showPreorders;
          }

          /** Set to true to show pre-ordered books. Defaults to false. */
          public List setShowPreorders(Boolean showPreorders) {
            this.showPreorders = showPreorders;
            return this;
          }

          /** Maximum number of results to return */
          @com.google.api.client.util.Key
          private Long maxResults;

          /** Maximum number of results to return

         [minimum: 0]
           */
          public Long getMaxResults() {
            return maxResults;
          }

          /** Maximum number of results to return */
          public List setMaxResults(Long maxResults) {
            this.maxResults = maxResults;
            return this;
          }

          /** Full-text search query string in this bookshelf. */
          @com.google.api.client.util.Key
          private String q;

          /** Full-text search query string in this bookshelf.
           */
          public String getQ() {
            return q;
          }

          /** Full-text search query string in this bookshelf. */
          public List setQ(String q) {
            this.q = q;
            return this;
          }

          /** String to identify the originator of this request. */
          @com.google.api.client.util.Key
          private String source;

          /** String to identify the originator of this request.
           */
          public String getSource() {
            return source;
          }

          /** String to identify the originator of this request. */
          public List setSource(String source) {
            this.source = source;
            return this;
          }

          /** Index of the first element to return (starts at 0) */
          @com.google.api.client.util.Key
          private Long startIndex;

          /** Index of the first element to return (starts at 0)

         [minimum: 0]
           */
          public Long getStartIndex() {
            return startIndex;
          }

          /** Index of the first element to return (starts at 0) */
          public List setStartIndex(Long startIndex) {
            this.startIndex = startIndex;
            return this;
          }

        }

      }
    }
    /**
     * An accessor for creating requests from the Readingpositions collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Books books = new Books(...);}
     *   {@code Books.Readingpositions.List request = books.readingpositions().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Readingpositions readingpositions() {
      return new Readingpositions();
    }

    /**
     * The "readingpositions" collection of methods.
     */
    public class Readingpositions {

      /**
       * Retrieves my reading position information for a volume.
       *
       * Create a request for the method "readingpositions.get".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param volumeId ID of volume for which to retrieve a reading position.
       * @return the request
       */
      public Get get(String volumeId) throws java.io.IOException {
        Get result = new Get(volumeId);
        initialize(result);
        return result;
      }

      public class Get extends BooksRequest<com.google.api.services.books.model.ReadingPosition> {

        private static final String REST_PATH = "mylibrary/readingpositions/{volumeId}";

        /**
         * Retrieves my reading position information for a volume.
         *
         * Create a request for the method "readingpositions.get".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
         * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param volumeId ID of volume for which to retrieve a reading position.
         * @since 1.13
         */
        protected Get(String volumeId) {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.ReadingPosition.class);
          this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get setAlt(String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setFields(String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUserIp(String userIp) {
          return (Get) super.setUserIp(userIp);
        }

        /** ID of volume for which to retrieve a reading position. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** ID of volume for which to retrieve a reading position.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** ID of volume for which to retrieve a reading position. */
        public Get setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public Get setSource(String source) {
          this.source = source;
          return this;
        }

        /** Volume content version for which this reading position is requested. */
        @com.google.api.client.util.Key
        private String contentVersion;

        /** Volume content version for which this reading position is requested.
         */
        public String getContentVersion() {
          return contentVersion;
        }

        /** Volume content version for which this reading position is requested. */
        public Get setContentVersion(String contentVersion) {
          this.contentVersion = contentVersion;
          return this;
        }

      }
      /**
       * Sets my reading position information for a volume.
       *
       * Create a request for the method "readingpositions.setPosition".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link SetPosition#execute()} method to invoke the remote operation.
       *
       * @param volumeId ID of volume for which to update the reading position.
       * @param timestamp RFC 3339 UTC format timestamp associated with this reading position.
       * @param position Position string for the new volume reading position.
       * @return the request
       */
      public SetPosition setPosition(String volumeId, String timestamp, String position) throws java.io.IOException {
        SetPosition result = new SetPosition(volumeId, timestamp, position);
        initialize(result);
        return result;
      }

      public class SetPosition extends BooksRequest<Void> {

        private static final String REST_PATH = "mylibrary/readingpositions/{volumeId}/setPosition";

        /**
         * Sets my reading position information for a volume.
         *
         * Create a request for the method "readingpositions.setPosition".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link SetPosition#execute()} method to invoke the remote operation. <p>
         * {@link SetPosition#initialize(AbstractGoogleClientRequest)} must be called to initialize this
         * instance immediately after invoking the constructor. </p>
         *
         * @param volumeId ID of volume for which to update the reading position.
         * @param timestamp RFC 3339 UTC format timestamp associated with this reading position.
         * @param position Position string for the new volume reading position.
         * @since 1.13
         */
        protected SetPosition(String volumeId, String timestamp, String position) {
          super(Books.this, "POST", REST_PATH, null, Void.class);
          this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
          this.timestamp = Preconditions.checkNotNull(timestamp, "Required parameter timestamp must be specified.");
          this.position = Preconditions.checkNotNull(position, "Required parameter position must be specified.");
        }

        @Override
        public SetPosition setAlt(String alt) {
          return (SetPosition) super.setAlt(alt);
        }

        @Override
        public SetPosition setFields(String fields) {
          return (SetPosition) super.setFields(fields);
        }

        @Override
        public SetPosition setKey(String key) {
          return (SetPosition) super.setKey(key);
        }

        @Override
        public SetPosition setOauthToken(String oauthToken) {
          return (SetPosition) super.setOauthToken(oauthToken);
        }

        @Override
        public SetPosition setPrettyPrint(Boolean prettyPrint) {
          return (SetPosition) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public SetPosition setQuotaUser(String quotaUser) {
          return (SetPosition) super.setQuotaUser(quotaUser);
        }

        @Override
        public SetPosition setUserIp(String userIp) {
          return (SetPosition) super.setUserIp(userIp);
        }

        /** ID of volume for which to update the reading position. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** ID of volume for which to update the reading position.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** ID of volume for which to update the reading position. */
        public SetPosition setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /** RFC 3339 UTC format timestamp associated with this reading position. */
        @com.google.api.client.util.Key
        private String timestamp;

        /** RFC 3339 UTC format timestamp associated with this reading position.
         */
        public String getTimestamp() {
          return timestamp;
        }

        /** RFC 3339 UTC format timestamp associated with this reading position. */
        public SetPosition setTimestamp(String timestamp) {
          this.timestamp = timestamp;
          return this;
        }

        /** Position string for the new volume reading position. */
        @com.google.api.client.util.Key
        private String position;

        /** Position string for the new volume reading position.
         */
        public String getPosition() {
          return position;
        }

        /** Position string for the new volume reading position. */
        public SetPosition setPosition(String position) {
          this.position = position;
          return this;
        }

        /** Random persistent device cookie optional on set position. */
        @com.google.api.client.util.Key
        private String deviceCookie;

        /** Random persistent device cookie optional on set position.
         */
        public String getDeviceCookie() {
          return deviceCookie;
        }

        /** Random persistent device cookie optional on set position. */
        public SetPosition setDeviceCookie(String deviceCookie) {
          this.deviceCookie = deviceCookie;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public SetPosition setSource(String source) {
          this.source = source;
          return this;
        }

        /** Volume content version for which this reading position applies. */
        @com.google.api.client.util.Key
        private String contentVersion;

        /** Volume content version for which this reading position applies.
         */
        public String getContentVersion() {
          return contentVersion;
        }

        /** Volume content version for which this reading position applies. */
        public SetPosition setContentVersion(String contentVersion) {
          this.contentVersion = contentVersion;
          return this;
        }

        /** Action that caused this reading position to be set. */
        @com.google.api.client.util.Key
        private String action;

        /** Action that caused this reading position to be set.
         */
        public String getAction() {
          return action;
        }

        /** Action that caused this reading position to be set. */
        public SetPosition setAction(String action) {
          this.action = action;
          return this;
        }

      }

    }
  }

  /**
   * An accessor for creating requests from the Volumes collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Books books = new Books(...);}
   *   {@code Books.Volumes.List request = books.volumes().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Volumes volumes() {
    return new Volumes();
  }

  /**
   * The "volumes" collection of methods.
   */
  public class Volumes {

    /**
     * Gets volume information for a single volume.
     *
     * Create a request for the method "volumes.get".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param volumeId ID of volume to retrieve.
     * @return the request
     */
    public Get get(String volumeId) throws java.io.IOException {
      Get result = new Get(volumeId);
      initialize(result);
      return result;
    }

    public class Get extends BooksRequest<com.google.api.services.books.model.Volume> {

      private static final String REST_PATH = "volumes/{volumeId}";

      /**
       * Gets volume information for a single volume.
       *
       * Create a request for the method "volumes.get".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param volumeId ID of volume to retrieve.
       * @since 1.13
       */
      protected Get(String volumeId) {
        super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Volume.class);
        this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** ID of volume to retrieve. */
      @com.google.api.client.util.Key
      private String volumeId;

      /** ID of volume to retrieve.
       */
      public String getVolumeId() {
        return volumeId;
      }

      /** ID of volume to retrieve. */
      public Get setVolumeId(String volumeId) {
        this.volumeId = volumeId;
        return this;
      }

      /** String to identify the originator of this request. */
      @com.google.api.client.util.Key
      private String source;

      /** String to identify the originator of this request.
       */
      public String getSource() {
        return source;
      }

      /** String to identify the originator of this request. */
      public Get setSource(String source) {
        this.source = source;
        return this;
      }

      /** ISO-3166-1 code to override the IP-based location. */
      @com.google.api.client.util.Key
      private String country;

      /** ISO-3166-1 code to override the IP-based location.
       */
      public String getCountry() {
        return country;
      }

      /** ISO-3166-1 code to override the IP-based location. */
      public Get setCountry(String country) {
        this.country = country;
        return this;
      }

      /** Restrict information returned to a set of selected fields. */
      @com.google.api.client.util.Key
      private String projection;

      /** Restrict information returned to a set of selected fields.
       */
      public String getProjection() {
        return projection;
      }

      /** Restrict information returned to a set of selected fields. */
      public Get setProjection(String projection) {
        this.projection = projection;
        return this;
      }

      /** Brand results for partner ID. */
      @com.google.api.client.util.Key
      private String partner;

      /** Brand results for partner ID.
       */
      public String getPartner() {
        return partner;
      }

      /** Brand results for partner ID. */
      public Get setPartner(String partner) {
        this.partner = partner;
        return this;
      }

    }
    /**
     * Performs a book search.
     *
     * Create a request for the method "volumes.list".
     *
     * This request holds the parameters needed by the the books server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param q Full-text search query string.
     * @return the request
     */
    public List list(String q) throws java.io.IOException {
      List result = new List(q);
      initialize(result);
      return result;
    }

    public class List extends BooksRequest<com.google.api.services.books.model.Volumes> {

      private static final String REST_PATH = "volumes";

      /**
       * Performs a book search.
       *
       * Create a request for the method "volumes.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param q Full-text search query string.
       * @since 1.13
       */
      protected List(String q) {
        super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Volumes.class);
        this.q = Preconditions.checkNotNull(q, "Required parameter q must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Full-text search query string. */
      @com.google.api.client.util.Key
      private String q;

      /** Full-text search query string.
       */
      public String getQ() {
        return q;
      }

      /** Full-text search query string. */
      public List setQ(String q) {
        this.q = q;
        return this;
      }

      /** Sort search results. */
      @com.google.api.client.util.Key
      private String orderBy;

      /** Sort search results.
       */
      public String getOrderBy() {
        return orderBy;
      }

      /** Sort search results. */
      public List setOrderBy(String orderBy) {
        this.orderBy = orderBy;
        return this;
      }

      /** Restrict information returned to a set of selected fields. */
      @com.google.api.client.util.Key
      private String projection;

      /** Restrict information returned to a set of selected fields.
       */
      public String getProjection() {
        return projection;
      }

      /** Restrict information returned to a set of selected fields. */
      public List setProjection(String projection) {
        this.projection = projection;
        return this;
      }

      /** Restrict search to this user's library. */
      @com.google.api.client.util.Key
      private String libraryRestrict;

      /** Restrict search to this user's library.
       */
      public String getLibraryRestrict() {
        return libraryRestrict;
      }

      /** Restrict search to this user's library. */
      public List setLibraryRestrict(String libraryRestrict) {
        this.libraryRestrict = libraryRestrict;
        return this;
      }

      /** Restrict results to books with this language code. */
      @com.google.api.client.util.Key
      private String langRestrict;

      /** Restrict results to books with this language code.
       */
      public String getLangRestrict() {
        return langRestrict;
      }

      /** Restrict results to books with this language code. */
      public List setLangRestrict(String langRestrict) {
        this.langRestrict = langRestrict;
        return this;
      }

      /** Set to true to show books available for preorder. Defaults to false. */
      @com.google.api.client.util.Key
      private Boolean showPreorders;

      /** Set to true to show books available for preorder. Defaults to false.
       */
      public Boolean getShowPreorders() {
        return showPreorders;
      }

      /** Set to true to show books available for preorder. Defaults to false. */
      public List setShowPreorders(Boolean showPreorders) {
        this.showPreorders = showPreorders;
        return this;
      }

      /** Restrict to books or magazines. */
      @com.google.api.client.util.Key
      private String printType;

      /** Restrict to books or magazines.
       */
      public String getPrintType() {
        return printType;
      }

      /** Restrict to books or magazines. */
      public List setPrintType(String printType) {
        this.printType = printType;
        return this;
      }

      /** Maximum number of results to return. */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** Maximum number of results to return.

     [minimum: 0] [maximum: 40]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return. */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** Filter search results. */
      @com.google.api.client.util.Key
      private String filter;

      /** Filter search results.
       */
      public String getFilter() {
        return filter;
      }

      /** Filter search results. */
      public List setFilter(String filter) {
        this.filter = filter;
        return this;
      }

      /** String to identify the originator of this request. */
      @com.google.api.client.util.Key
      private String source;

      /** String to identify the originator of this request.
       */
      public String getSource() {
        return source;
      }

      /** String to identify the originator of this request. */
      public List setSource(String source) {
        this.source = source;
        return this;
      }

      /** Index of the first result to return (starts at 0) */
      @com.google.api.client.util.Key
      private Long startIndex;

      /** Index of the first result to return (starts at 0)

     [minimum: 0]
       */
      public Long getStartIndex() {
        return startIndex;
      }

      /** Index of the first result to return (starts at 0) */
      public List setStartIndex(Long startIndex) {
        this.startIndex = startIndex;
        return this;
      }

      /** Restrict to volumes by download availability. */
      @com.google.api.client.util.Key
      private String download;

      /** Restrict to volumes by download availability.
       */
      public String getDownload() {
        return download;
      }

      /** Restrict to volumes by download availability. */
      public List setDownload(String download) {
        this.download = download;
        return this;
      }

      /** Restrict and brand results for partner ID. */
      @com.google.api.client.util.Key
      private String partner;

      /** Restrict and brand results for partner ID.
       */
      public String getPartner() {
        return partner;
      }

      /** Restrict and brand results for partner ID. */
      public List setPartner(String partner) {
        this.partner = partner;
        return this;
      }

    }

    /**
     * An accessor for creating requests from the Associated collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Books books = new Books(...);}
     *   {@code Books.Associated.List request = books.associated().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Associated associated() {
      return new Associated();
    }

    /**
     * The "associated" collection of methods.
     */
    public class Associated {

      /**
       * Return a list of associated books.
       *
       * Create a request for the method "associated.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param volumeId ID of the source volume.
       * @return the request
       */
      public List list(String volumeId) throws java.io.IOException {
        List result = new List(volumeId);
        initialize(result);
        return result;
      }

      public class List extends BooksRequest<com.google.api.services.books.model.Volumes> {

        private static final String REST_PATH = "volumes/{volumeId}/associated";

        /**
         * Return a list of associated books.
         *
         * Create a request for the method "associated.list".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param volumeId ID of the source volume.
         * @since 1.13
         */
        protected List(String volumeId) {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Volumes.class);
          this.volumeId = Preconditions.checkNotNull(volumeId, "Required parameter volumeId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** ID of the source volume. */
        @com.google.api.client.util.Key
        private String volumeId;

        /** ID of the source volume.
         */
        public String getVolumeId() {
          return volumeId;
        }

        /** ID of the source volume. */
        public List setVolumeId(String volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /**
       * ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'. Used for generating
       * recommendations.
       */
        @com.google.api.client.util.Key
        private String locale;

        /** ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'. Used for generating recommendations.
         */
        public String getLocale() {
          return locale;
        }

        /**
       * ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'. Used for generating
       * recommendations.
       */
        public List setLocale(String locale) {
          this.locale = locale;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public List setSource(String source) {
          this.source = source;
          return this;
        }

        /** Association type. */
        @com.google.api.client.util.Key
        private String association;

        /** Association type.
         */
        public String getAssociation() {
          return association;
        }

        /** Association type. */
        public List setAssociation(String association) {
          this.association = association;
          return this;
        }

      }

    }
    /**
     * An accessor for creating requests from the Mybooks collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Books books = new Books(...);}
     *   {@code Books.Mybooks.List request = books.mybooks().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Mybooks mybooks() {
      return new Mybooks();
    }

    /**
     * The "mybooks" collection of methods.
     */
    public class Mybooks {

      /**
       * Return a list of books in My Library.
       *
       * Create a request for the method "mybooks.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @return the request
       */
      public List list() throws java.io.IOException {
        List result = new List();
        initialize(result);
        return result;
      }

      public class List extends BooksRequest<com.google.api.services.books.model.Volumes> {

        private static final String REST_PATH = "volumes/mybooks";

        /**
         * Return a list of books in My Library.
         *
         * Create a request for the method "mybooks.list".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @since 1.13
         */
        protected List() {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Volumes.class);
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /**
       * ISO-639-1 language and ISO-3166-1 country code. Ex:'en_US'. Used for generating
       * recommendations.
       */
        @com.google.api.client.util.Key
        private String locale;

        /** ISO-639-1 language and ISO-3166-1 country code. Ex:'en_US'. Used for generating recommendations.
         */
        public String getLocale() {
          return locale;
        }

        /**
       * ISO-639-1 language and ISO-3166-1 country code. Ex:'en_US'. Used for generating
       * recommendations.
       */
        public List setLocale(String locale) {
          this.locale = locale;
          return this;
        }

        /** Index of the first result to return (starts at 0) */
        @com.google.api.client.util.Key
        private Long startIndex;

        /** Index of the first result to return (starts at 0)

       [minimum: 0]
         */
        public Long getStartIndex() {
          return startIndex;
        }

        /** Index of the first result to return (starts at 0) */
        public List setStartIndex(Long startIndex) {
          this.startIndex = startIndex;
          return this;
        }

        /** Maximum number of results to return. */
        @com.google.api.client.util.Key
        private Long maxResults;

        /** Maximum number of results to return.

       [minimum: 0] [maximum: 100]
         */
        public Long getMaxResults() {
          return maxResults;
        }

        /** Maximum number of results to return. */
        public List setMaxResults(Long maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public List setSource(String source) {
          this.source = source;
          return this;
        }

        /** How the book was aquired */
        @com.google.api.client.util.Key
        private java.util.List<String> acquireMethod;

        /** How the book was aquired
         */
        public java.util.List<String> getAcquireMethod() {
          return acquireMethod;
        }

        /** How the book was aquired */
        public List setAcquireMethod(java.util.List<String> acquireMethod) {
          this.acquireMethod = acquireMethod;
          return this;
        }

        /**
       * The processing state of the user uploaded volumes to be returned. Applicable only if the
       * UPLOADED is specified in the acquireMethod.
       */
        @com.google.api.client.util.Key
        private java.util.List<String> processingState;

        /** The processing state of the user uploaded volumes to be returned. Applicable only if the UPLOADED
       is specified in the acquireMethod.
         */
        public java.util.List<String> getProcessingState() {
          return processingState;
        }

        /**
       * The processing state of the user uploaded volumes to be returned. Applicable only if the
       * UPLOADED is specified in the acquireMethod.
       */
        public List setProcessingState(java.util.List<String> processingState) {
          this.processingState = processingState;
          return this;
        }

      }

    }
    /**
     * An accessor for creating requests from the Recommended collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Books books = new Books(...);}
     *   {@code Books.Recommended.List request = books.recommended().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Recommended recommended() {
      return new Recommended();
    }

    /**
     * The "recommended" collection of methods.
     */
    public class Recommended {

      /**
       * Return a list of recommended books for the current user.
       *
       * Create a request for the method "recommended.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @return the request
       */
      public List list() throws java.io.IOException {
        List result = new List();
        initialize(result);
        return result;
      }

      public class List extends BooksRequest<com.google.api.services.books.model.Volumes> {

        private static final String REST_PATH = "volumes/recommended";

        /**
         * Return a list of recommended books for the current user.
         *
         * Create a request for the method "recommended.list".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @since 1.13
         */
        protected List() {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Volumes.class);
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /**
       * ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'. Used for generating
       * recommendations.
       */
        @com.google.api.client.util.Key
        private String locale;

        /** ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'. Used for generating recommendations.
         */
        public String getLocale() {
          return locale;
        }

        /**
       * ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'. Used for generating
       * recommendations.
       */
        public List setLocale(String locale) {
          this.locale = locale;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public List setSource(String source) {
          this.source = source;
          return this;
        }

      }

    }
    /**
     * An accessor for creating requests from the Useruploaded collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Books books = new Books(...);}
     *   {@code Books.Useruploaded.List request = books.useruploaded().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Useruploaded useruploaded() {
      return new Useruploaded();
    }

    /**
     * The "useruploaded" collection of methods.
     */
    public class Useruploaded {

      /**
       * Return a list of books uploaded by the current user.
       *
       * Create a request for the method "useruploaded.list".
       *
       * This request holds the parameters needed by the the books server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @return the request
       */
      public List list() throws java.io.IOException {
        List result = new List();
        initialize(result);
        return result;
      }

      public class List extends BooksRequest<com.google.api.services.books.model.Volumes> {

        private static final String REST_PATH = "volumes/useruploaded";

        /**
         * Return a list of books uploaded by the current user.
         *
         * Create a request for the method "useruploaded.list".
         *
         * This request holds the parameters needed by the the books server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @since 1.13
         */
        protected List() {
          super(Books.this, "GET", REST_PATH, null, com.google.api.services.books.model.Volumes.class);
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /**
       * ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'. Used for generating
       * recommendations.
       */
        @com.google.api.client.util.Key
        private String locale;

        /** ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'. Used for generating recommendations.
         */
        public String getLocale() {
          return locale;
        }

        /**
       * ISO-639-1 language and ISO-3166-1 country code. Ex: 'en_US'. Used for generating
       * recommendations.
       */
        public List setLocale(String locale) {
          this.locale = locale;
          return this;
        }

        /**
       * The ids of the volumes to be returned. If not specified all that match the processingState
       * are returned.
       */
        @com.google.api.client.util.Key
        private java.util.List<String> volumeId;

        /** The ids of the volumes to be returned. If not specified all that match the processingState are
       returned.
         */
        public java.util.List<String> getVolumeId() {
          return volumeId;
        }

        /**
       * The ids of the volumes to be returned. If not specified all that match the processingState
       * are returned.
       */
        public List setVolumeId(java.util.List<String> volumeId) {
          this.volumeId = volumeId;
          return this;
        }

        /** Maximum number of results to return. */
        @com.google.api.client.util.Key
        private Long maxResults;

        /** Maximum number of results to return.

       [minimum: 0] [maximum: 40]
         */
        public Long getMaxResults() {
          return maxResults;
        }

        /** Maximum number of results to return. */
        public List setMaxResults(Long maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        /** String to identify the originator of this request. */
        @com.google.api.client.util.Key
        private String source;

        /** String to identify the originator of this request.
         */
        public String getSource() {
          return source;
        }

        /** String to identify the originator of this request. */
        public List setSource(String source) {
          this.source = source;
          return this;
        }

        /** Index of the first result to return (starts at 0) */
        @com.google.api.client.util.Key
        private Long startIndex;

        /** Index of the first result to return (starts at 0)

       [minimum: 0]
         */
        public Long getStartIndex() {
          return startIndex;
        }

        /** Index of the first result to return (starts at 0) */
        public List setStartIndex(Long startIndex) {
          this.startIndex = startIndex;
          return this;
        }

        /** The processing state of the user uploaded volumes to be returned. */
        @com.google.api.client.util.Key
        private java.util.List<String> processingState;

        /** The processing state of the user uploaded volumes to be returned.
         */
        public java.util.List<String> getProcessingState() {
          return processingState;
        }

        /** The processing state of the user uploaded volumes to be returned. */
        public List setProcessingState(java.util.List<String> processingState) {
          this.processingState = processingState;
          return this;
        }

      }

    }
  }

  /**
   * Builder for {@link Books}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Books}. */
    @Override
    public Books build() {
      return new Books(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link BooksRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setBooksRequestInitializer(
        BooksRequestInitializer booksRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(booksRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
