/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.books.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Annotation.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Books API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Annotation extends GenericJson {

  /**
   * Anchor text after excerpt. For requests, if the user bookmarked a screen that has no flowing
   * text on it, then this field should be empty.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String afterSelectedText;

  /**
   * Anchor text before excerpt. For requests, if the user bookmarked a screen that has no flowing
   * text on it, then this field should be empty.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String beforeSelectedText;

  /**
   * Selection ranges sent from the client.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ClientVersionRanges clientVersionRanges;

  /**
   * Timestamp for the created time of this annotation.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime created;

  /**
   * Selection ranges for the most recent content version.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private CurrentVersionRanges currentVersionRanges;

  /**
   * User-created data for this annotation.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String data;

  /**
   * Indicates that this annotation is deleted.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean deleted;

  /**
   * The highlight style for this annotation.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String highlightStyle;

  /**
   * Id of this annotation, in the form of a GUID.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * Resource type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The layer this annotation is for.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String layerId;

  /**
   * Pages that this annotation spans.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> pageIds;

  /**
   * Excerpt from the volume.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selectedText;

  /**
   * URL to this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * Timestamp for the last time this annotation was modified.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * The volume that this annotation belongs to.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String volumeId;

  /**
   * Anchor text after excerpt. For requests, if the user bookmarked a screen that has no flowing
   * text on it, then this field should be empty.
   * The value returned may be {@code null}.
   */
  public String getAfterSelectedText() {
    return afterSelectedText;
  }

  /**
   * Anchor text after excerpt. For requests, if the user bookmarked a screen that has no flowing
   * text on it, then this field should be empty.
   * The value set may be {@code null}.
   */
  public Annotation setAfterSelectedText(String afterSelectedText) {
    this.afterSelectedText = afterSelectedText;
    return this;
  }

  /**
   * Anchor text before excerpt. For requests, if the user bookmarked a screen that has no flowing
   * text on it, then this field should be empty.
   * The value returned may be {@code null}.
   */
  public String getBeforeSelectedText() {
    return beforeSelectedText;
  }

  /**
   * Anchor text before excerpt. For requests, if the user bookmarked a screen that has no flowing
   * text on it, then this field should be empty.
   * The value set may be {@code null}.
   */
  public Annotation setBeforeSelectedText(String beforeSelectedText) {
    this.beforeSelectedText = beforeSelectedText;
    return this;
  }

  /**
   * Selection ranges sent from the client.
   * The value returned may be {@code null}.
   */
  public ClientVersionRanges getClientVersionRanges() {
    return clientVersionRanges;
  }

  /**
   * Selection ranges sent from the client.
   * The value set may be {@code null}.
   */
  public Annotation setClientVersionRanges(ClientVersionRanges clientVersionRanges) {
    this.clientVersionRanges = clientVersionRanges;
    return this;
  }

  /**
   * Timestamp for the created time of this annotation.
   * The value returned may be {@code null}.
   */
  public DateTime getCreated() {
    return created;
  }

  /**
   * Timestamp for the created time of this annotation.
   * The value set may be {@code null}.
   */
  public Annotation setCreated(DateTime created) {
    this.created = created;
    return this;
  }

  /**
   * Selection ranges for the most recent content version.
   * The value returned may be {@code null}.
   */
  public CurrentVersionRanges getCurrentVersionRanges() {
    return currentVersionRanges;
  }

  /**
   * Selection ranges for the most recent content version.
   * The value set may be {@code null}.
   */
  public Annotation setCurrentVersionRanges(CurrentVersionRanges currentVersionRanges) {
    this.currentVersionRanges = currentVersionRanges;
    return this;
  }

  /**
   * User-created data for this annotation.
   * The value returned may be {@code null}.
   */
  public String getData() {
    return data;
  }

  /**
   * User-created data for this annotation.
   * The value set may be {@code null}.
   */
  public Annotation setData(String data) {
    this.data = data;
    return this;
  }

  /**
   * Indicates that this annotation is deleted.
   * The value returned may be {@code null}.
   */
  public Boolean getDeleted() {
    return deleted;
  }

  /**
   * Indicates that this annotation is deleted.
   * The value set may be {@code null}.
   */
  public Annotation setDeleted(Boolean deleted) {
    this.deleted = deleted;
    return this;
  }

  /**
   * The highlight style for this annotation.
   * The value returned may be {@code null}.
   */
  public String getHighlightStyle() {
    return highlightStyle;
  }

  /**
   * The highlight style for this annotation.
   * The value set may be {@code null}.
   */
  public Annotation setHighlightStyle(String highlightStyle) {
    this.highlightStyle = highlightStyle;
    return this;
  }

  /**
   * Id of this annotation, in the form of a GUID.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Id of this annotation, in the form of a GUID.
   * The value set may be {@code null}.
   */
  public Annotation setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * Resource type.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource type.
   * The value set may be {@code null}.
   */
  public Annotation setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The layer this annotation is for.
   * The value returned may be {@code null}.
   */
  public String getLayerId() {
    return layerId;
  }

  /**
   * The layer this annotation is for.
   * The value set may be {@code null}.
   */
  public Annotation setLayerId(String layerId) {
    this.layerId = layerId;
    return this;
  }

  /**
   * Pages that this annotation spans.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getPageIds() {
    return pageIds;
  }

  /**
   * Pages that this annotation spans.
   * The value set may be {@code null}.
   */
  public Annotation setPageIds(java.util.List<String> pageIds) {
    this.pageIds = pageIds;
    return this;
  }

  /**
   * Excerpt from the volume.
   * The value returned may be {@code null}.
   */
  public String getSelectedText() {
    return selectedText;
  }

  /**
   * Excerpt from the volume.
   * The value set may be {@code null}.
   */
  public Annotation setSelectedText(String selectedText) {
    this.selectedText = selectedText;
    return this;
  }

  /**
   * URL to this resource.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * URL to this resource.
   * The value set may be {@code null}.
   */
  public Annotation setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * Timestamp for the last time this annotation was modified.
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * Timestamp for the last time this annotation was modified.
   * The value set may be {@code null}.
   */
  public Annotation setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * The volume that this annotation belongs to.
   * The value returned may be {@code null}.
   */
  public String getVolumeId() {
    return volumeId;
  }

  /**
   * The volume that this annotation belongs to.
   * The value set may be {@code null}.
   */
  public Annotation setVolumeId(String volumeId) {
    this.volumeId = volumeId;
    return this;
  }

  /**
   * Selection ranges sent from the client.
   */
  public static final class ClientVersionRanges extends GenericJson {

    /**
     * Range in CFI format for this annotation sent by client.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private BooksAnnotationsRange cfiRange;

    /**
     * Content version the client sent in.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String contentVersion;

    /**
     * Range in GB image format for this annotation sent by client.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private BooksAnnotationsRange gbImageRange;

    /**
     * Range in GB text format for this annotation sent by client.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private BooksAnnotationsRange gbTextRange;

    /**
     * Range in image CFI format for this annotation sent by client.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private BooksAnnotationsRange imageCfiRange;

    /**
     * Range in CFI format for this annotation sent by client.
     * The value returned may be {@code null}.
     */
    public BooksAnnotationsRange getCfiRange() {
      return cfiRange;
    }

    /**
     * Range in CFI format for this annotation sent by client.
     * The value set may be {@code null}.
     */
    public ClientVersionRanges setCfiRange(BooksAnnotationsRange cfiRange) {
      this.cfiRange = cfiRange;
      return this;
    }

    /**
     * Content version the client sent in.
     * The value returned may be {@code null}.
     */
    public String getContentVersion() {
      return contentVersion;
    }

    /**
     * Content version the client sent in.
     * The value set may be {@code null}.
     */
    public ClientVersionRanges setContentVersion(String contentVersion) {
      this.contentVersion = contentVersion;
      return this;
    }

    /**
     * Range in GB image format for this annotation sent by client.
     * The value returned may be {@code null}.
     */
    public BooksAnnotationsRange getGbImageRange() {
      return gbImageRange;
    }

    /**
     * Range in GB image format for this annotation sent by client.
     * The value set may be {@code null}.
     */
    public ClientVersionRanges setGbImageRange(BooksAnnotationsRange gbImageRange) {
      this.gbImageRange = gbImageRange;
      return this;
    }

    /**
     * Range in GB text format for this annotation sent by client.
     * The value returned may be {@code null}.
     */
    public BooksAnnotationsRange getGbTextRange() {
      return gbTextRange;
    }

    /**
     * Range in GB text format for this annotation sent by client.
     * The value set may be {@code null}.
     */
    public ClientVersionRanges setGbTextRange(BooksAnnotationsRange gbTextRange) {
      this.gbTextRange = gbTextRange;
      return this;
    }

    /**
     * Range in image CFI format for this annotation sent by client.
     * The value returned may be {@code null}.
     */
    public BooksAnnotationsRange getImageCfiRange() {
      return imageCfiRange;
    }

    /**
     * Range in image CFI format for this annotation sent by client.
     * The value set may be {@code null}.
     */
    public ClientVersionRanges setImageCfiRange(BooksAnnotationsRange imageCfiRange) {
      this.imageCfiRange = imageCfiRange;
      return this;
    }

  }

  /**
   * Selection ranges for the most recent content version.
   */
  public static final class CurrentVersionRanges extends GenericJson {

    /**
     * Range in CFI format for this annotation for version above.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private BooksAnnotationsRange cfiRange;

    /**
     * Content version applicable to ranges below.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String contentVersion;

    /**
     * Range in GB image format for this annotation for version above.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private BooksAnnotationsRange gbImageRange;

    /**
     * Range in GB text format for this annotation for version above.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private BooksAnnotationsRange gbTextRange;

    /**
     * Range in image CFI format for this annotation for version above.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private BooksAnnotationsRange imageCfiRange;

    /**
     * Range in CFI format for this annotation for version above.
     * The value returned may be {@code null}.
     */
    public BooksAnnotationsRange getCfiRange() {
      return cfiRange;
    }

    /**
     * Range in CFI format for this annotation for version above.
     * The value set may be {@code null}.
     */
    public CurrentVersionRanges setCfiRange(BooksAnnotationsRange cfiRange) {
      this.cfiRange = cfiRange;
      return this;
    }

    /**
     * Content version applicable to ranges below.
     * The value returned may be {@code null}.
     */
    public String getContentVersion() {
      return contentVersion;
    }

    /**
     * Content version applicable to ranges below.
     * The value set may be {@code null}.
     */
    public CurrentVersionRanges setContentVersion(String contentVersion) {
      this.contentVersion = contentVersion;
      return this;
    }

    /**
     * Range in GB image format for this annotation for version above.
     * The value returned may be {@code null}.
     */
    public BooksAnnotationsRange getGbImageRange() {
      return gbImageRange;
    }

    /**
     * Range in GB image format for this annotation for version above.
     * The value set may be {@code null}.
     */
    public CurrentVersionRanges setGbImageRange(BooksAnnotationsRange gbImageRange) {
      this.gbImageRange = gbImageRange;
      return this;
    }

    /**
     * Range in GB text format for this annotation for version above.
     * The value returned may be {@code null}.
     */
    public BooksAnnotationsRange getGbTextRange() {
      return gbTextRange;
    }

    /**
     * Range in GB text format for this annotation for version above.
     * The value set may be {@code null}.
     */
    public CurrentVersionRanges setGbTextRange(BooksAnnotationsRange gbTextRange) {
      this.gbTextRange = gbTextRange;
      return this;
    }

    /**
     * Range in image CFI format for this annotation for version above.
     * The value returned may be {@code null}.
     */
    public BooksAnnotationsRange getImageCfiRange() {
      return imageCfiRange;
    }

    /**
     * Range in image CFI format for this annotation for version above.
     * The value set may be {@code null}.
     */
    public CurrentVersionRanges setImageCfiRange(BooksAnnotationsRange imageCfiRange) {
      this.imageCfiRange = imageCfiRange;
      return this;
    }

  }

}
